/*
 *******************************************************************************
 *
 *  Copyright 2025 RIEGL Laser Measurement Systems
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *  SPDX-License-Identifier: Apache-2.0
 *
 *******************************************************************************
 */
/*!
 *******************************************************************************
 *
 * \author  RIEGL LMS GmbH, Austria
 * \brief   Description of RIEGL RDB 2 database meta data items.
 * \version 2015-10-27/AW: Initial version
 * \version 2015-11-25/AW: Item "Geo Tag" added
 * \version 2016-10-27/AW: Item "Voxel Information" added
 * \version 2016-11-17/AW: Item "Voxel Information" updated
 * \version 2016-12-12/AW: Item "Range Statistics" added
 * \version 2017-03-08/AW: Item "Plane Patch Statistics" added
 * \version 2017-04-05/AW: Items "Atmosphere" and "Geometric Scale Factor" added
 * \version 2017-08-22/AW: Items for waveform sample block and value files added
 * \version 2017-10-24/AW: Item "Gaussian Decomposition" added
 * \version 2017-11-13/AW: Item "riegl.scan_pattern" updated
 * \version 2017-11-21/AW: Item "riegl.trajectory_info" added
 * \version 2018-01-11/AW: Item "riegl.beam_geometry" added
 * \version 2018-01-15/AW: Item "riegl.reflectance_calculation" added
 * \version 2018-01-15/AW: Item "riegl.near_range_correction" added
 * \version 2018-01-15/AW: Item "riegl.device_geometry" added
 * \version 2018-02-13/AW: Item "riegl.notch_filter" added
 * \version 2018-03-08/AW: Item "riegl.window_echo_correction" added
 * \version 2018-03-15/AW: Item "riegl.pulse_position_modulation" added
 * \version 2018-05-24/AW: Item "riegl.pixel_info" added
 * \version 2018-06-08/AW: Item "riegl.shot_info" added
 * \version 2018-06-08/AW: Item "riegl.echo_info" added
 * \version 2018-06-14/AW: Item "riegl.mta_settings" added
 * \version 2018-06-14/AW: Item "riegl.receiver_internals" added
 * \version 2018-06-14/AW: Item "riegl.device_output_limits" added
 * \version 2018-06-26/AW: Schema: replace "number" with "integer" if applicable
 * \version 2018-07-09/AW: Item "riegl.pose_estimation" added
 * \version 2018-07-09/AW: Item "riegl.pose_sensors" added
 * \version 2018-09-20/AW: Item "riegl.pointcloud_info" added
 * \version 2018-11-08/AW: Item "riegl.scan_pattern" updated
 * \version 2018-11-13/AW: Item "riegl.receiver_internals" updated
 * \version 2019-03-06/AW: Item "riegl.receiver_internals" updated
 * \version 2019-03-21/AW: Item "riegl.device_geometry" updated
 * \version 2019-04-15/AW: Item "riegl.point_attribute_groups" added
 * \version 2019-04-30/AW: Item "riegl.waveform_settings" added
 * \version 2019-10-03/AW: Item "riegl.angular_notch_filter" added
 * \version 2019-10-03/AW: Item "riegl.noise_estimates" added
 * \version 2019-10-25/AW: Item "riegl.window_analysis" added
 * \version 2019-11-06/AW: Item "riegl.georeferencing_parameters" added
 * \version 2019-11-27/AW: Item "riegl.plane_patch_matching" added
 * \version 2019-12-13/AW: Items for tie-/control objects added
 * \version 2019-12-19/AW: Items for tie-/control objects added
 * \version 2020-02-04/AW: Item "riegl.detection_probability" added
 * \version 2020-02-04/AW: Item "riegl.licenses" added
 * \version 2020-04-27/AW: Item "riegl.waveform_info" updated (schema+example)
 * \version 2020-09-03/AW: Item "riegl.reflectance_correction" added
 * \version 2020-09-10/AW: Item "riegl.device_geometry_passive_channel" added
 * \version 2020-09-25/AW: Item "riegl.georeferencing_parameters" updated
 * \version 2020-09-25/AW: Item "riegl.trajectory_info" updated
 * \version 2020-09-29/AW: Item "riegl.temperature_calculation" added
 * \version 2020-10-23/AW: Item "riegl.exponential_decomposition" added (#3709)
 * \version 2020-11-30/AW: Item "riegl.notch_filter" updated (schema)
 * \version 2020-12-02/AW: Item "riegl.georeferencing_parameters" updated (schema)
 * \version 2021-02-02/AW: Item "riegl.plane_slope_class_info" added (rdbplanes/#7)
 * \version 2021-02-16/AW: Item "riegl.device_output_limits" updated (schema, #3811)
 * \version 2021-03-03/AW: Item "riegl.exponential_decomposition" updated (schema, #3822)
 * \version 2021-03-03/AW: Item "riegl.waveform_averaging_settings" added (#3821)
 * \version 2021-04-01/AW: Item "riegl.voxel_info" updated (schema, #3854)
 * \version 2021-04-16/AW: Item "riegl.voxel_info" updated (schema, #3866)
 * \version 2021-09-30/AW: Item "riegl.waveform_info" updated (schema+example, #4016)
 * \version 2021-10-04/AW: Improved spelling of the descriptions of some items
 * \version 2021-11-04/AW: Rename "riegl.record_names" to "riegl.item_names" (#4034)
 * \version 2022-03-11/AW: Item "riegl.devices" added (#4162)
 * \version 2022-03-14/AW: Item "riegl.stored_filters" added (#4164)
 * \version 2022-09-20/AW: Fix typos in schema of "riegl.georeferencing_parameters"
 * \version 2022-09-30/AW: Item "riegl.system_description" added (#4368)
 * \version 2022-10-10/AW: Correction of typos in the titles of some entries
 * \version 2022-10-20/AW: Item "riegl.stored_filters" updated (example, #4164)
 * \version 2023-01-19/AW: Item "riegl.ttip_configuration" added (#4449)
 * \version 2024-09-26/AW: Item "riegl.dyntrig" added (#5310)
 *
 *******************************************************************************
 */

#ifndef RDB_354CFFB3_BDAA_4E38_98C8_9C09D0C0AD87
#define RDB_354CFFB3_BDAA_4E38_98C8_9C09D0C0AD87

#include <vector>
#include <string>
#include <cstdlib>
#include <cstdint>

namespace riegl {
namespace rdb {
namespace pointcloud {

// Meta data item definition version
const std::string RDB_META_DATA_ITEMS_VERSION = "1.1.54";
const std::string RDB_META_DATA_ITEMS_DATE = "2023-01-19";

// Meta data item states
const unsigned char RDB_STATUS_REQUIRED = 1; // mandatory item
const unsigned char RDB_STATUS_OPTIONAL = 2; // optional item

// Container record for meta data item details
struct MetaDataItemInfo
{
    std::string   name;
    std::string   title;
    std::string   description;
    unsigned char status;
    std::string   schema;
    std::string   example;

    operator const std::string&() const { return name; }
};

// Angular notch filter parameters for window glass echoes
const MetaDataItemInfo RDB_RIEGL_ANGULAR_NOTCH_FILTER = {
    /* name        */ "riegl.angular_notch_filter",
    /* title       */ "Angular Notch Filter",
    /* description */ "Angular notch filter parameters for window glass echoes",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"properties\":{\"angle\":{\"type\":\"array\",\"items\":{\"type\""
    ":\"number\"},\"description\":\"Angle [deg]\"},\"amplitude_mean\":{\"type\":\"arra"
    "y\",\"items\":{\"type\":\"number\"},\"description\":\"Mean amplitude [dB]\"},\"ran"
    "ge_mean\":{\"type\":\"array\",\"items\":{\"type\":\"number\"},\"description\":\"Mean"
    " range [m]\"}},\"title\":\"Angular Notch Filter\",\"$schema\":\"http://json-sc"
    "hema.org/draft-04/schema#\",\"description\":\"Angular notch filter "
    "parameters for window glass "
    "echoes\",\"required\":[\"angle\",\"range_mean\",\"amplitude_mean\"]}"
    ,
    /* example: */
    "{\"angle\":[14.0,15.0,16.0,17.0,18.0,19.0,20.0,21.0,22.0,23.0,24.0],\"amp"
    "litude_mean\":[3.780913,3.780913,3.480913,3.120913,2.850913,2.720913,2."
    "680913,2.610913,2.530913,2.570913,2.570913],\"range_mean\":[0.094,0.094,"
    "0.09075,0.08675,0.0815,0.0775,0.074,0.071,0.068,0.0675,0.06475]}"
};

// Atmospheric parameters
const MetaDataItemInfo RDB_RIEGL_ATMOSPHERE = {
    /* name        */ "riegl.atmosphere",
    /* title       */ "Atmosphere",
    /* description */ "Atmospheric parameters",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"properties\":{\"pressure_sl\":{\"type\":\"number\",\"descrip"
    "tion\":\"Atmospheric pressure at sea level "
    "[mbar]\"},\"group_velocity\":{\"type\":\"number\",\"description\":\"Group "
    "velocity of laser beam "
    "[m/s]\"},\"pressure\":{\"type\":\"number\",\"description\":\"Pressure along "
    "measurment path "
    "[mbar]\"},\"attenuation\":{\"type\":\"number\",\"description\":\"Atmospheric "
    "attenuation [1/km]\"},\"amsl\":{\"type\":\"number\",\"description\":\"Height "
    "above mean sea level (AMSL) "
    "[m]\"},\"temperature\":{\"type\":\"number\",\"description\":\"Temperature along "
    "measurement path "
    "[\\u00b0C]\"},\"wavelength\":{\"type\":\"number\",\"description\":\"Laser "
    "wavelength "
    "[nm]\"},\"rel_humidity\":{\"type\":\"number\",\"description\":\"Relative "
    "humidity along measurement path [%]\"}},\"title\":\"Atmospheric Parameters"
    "\",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"description\":\"A"
    "tmospheric parameters\",\"required\":[\"temperature\",\"pressure\",\"rel_humid"
    "ity\",\"pressure_sl\",\"amsl\",\"group_velocity\",\"attenuation\",\"wavelength\"]"
    "}"
    ,
    /* example: */
    "{\"pressure_sl\":970,\"group_velocity\":299711000.0,\"pressure\":970,\"attenu"
    "ation\":0.028125,\"amsl\":0,\"temperature\":7,\"wavelength\":1550,\"rel_humidi"
    "ty\":63}"
};

// Laser beam geometry details
const MetaDataItemInfo RDB_RIEGL_BEAM_GEOMETRY = {
    /* name        */ "riegl.beam_geometry",
    /* title       */ "Beam Geometry",
    /* description */ "Laser beam geometry details",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"properties\":{\"beam_exit_diameter\":{\"type\":\"number\",\""
    "minimum\":0,\"description\":\"Beam width at exit aperture [m]\",\"exclusiveM"
    "inimum\":false},\"beam_divergence\":{\"type\":\"number\",\"minimum\":0,\"descrip"
    "tion\":\"Beam divergence in far field "
    "[rad]\",\"exclusiveMinimum\":false}},\"title\":\"Beam Geometry\",\"$schema\":\"h"
    "ttp://json-schema.org/draft-04/schema#\",\"description\":\"Laser beam "
    "geometry details\",\"required\":[\"beam_exit_diameter\",\"beam_divergence\"]}"
    ,
    /* example: */
    "{\"beam_exit_diameter\":0.0072,\"beam_divergence\":0.0003}"
};

// List of control object type definitions
const MetaDataItemInfo RDB_RIEGL_CONTROL_OBJECT_CATALOG = {
    /* name        */ "riegl.control_object_catalog",
    /* title       */ "Control Object Catalog",
    /* description */ "List of control object type definitions",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"properties\":{\"types\":{\"type\":\"array\",\"uniqueItems\":t"
    "rue,\"items\":{\"type\":\"object\",\"oneOf\":[{\"$ref\":\"#/definitions/rectangle"
    "\"},{\"$ref\":\"#/definitions/checkerboard2x2\"},{\"$ref\":\"#/definitions/che"
    "vron\"},{\"$ref\":\"#/definitions/circular_disk\"},{\"$ref\":\"#/definitions/c"
    "ylinder\"},{\"$ref\":\"#/definitions/sphere\"},{\"$ref\":\"#/definitions/round"
    "_corner_cube_prism\"}]}}},\"title\":\"Control Object Catalog\",\"$schema\":\"h"
    "ttp://json-schema.org/draft-04/schema#\",\"description\":\"List of control"
    " object type definitions\",\"definitions\":{\"checkerboard2x2\":{\"type\":\"ob"
    "ject\",\"allOf\":[{\"$ref\":\"#/definitions/common\"},{\"type\":\"object\",\"prope"
    "rties\":{\"square_length\":{\"type\":\"number\",\"minimum\":0,\"description\":\"le"
    "ngth of a square of the checkerboard in meters\",\"exclusiveMinimum\":tru"
    "e},\"shape\":{\"type\":\"string\",\"enum\":[\"checkerboard2x2\"],\"description\":\""
    "shape identifier\"}},\"required\":[\"shape\",\"square_length\"],\"description\""
    ":\"checkerboard specific properties\"}],\"description\":\"checkerboard 2 by"
    " 2\"},\"circular_disk\":{\"type\":\"object\",\"allOf\":[{\"$ref\":\"#/definitions/"
    "common\"},{\"type\":\"object\",\"properties\":{\"diameter\":{\"type\":\"number\",\"m"
    "inimum\":0,\"description\":\"diameter in meters\",\"exclusiveMinimum\":true},"
    "\"offset\":{\"type\":\"number\",\"description\":\"offset in meters, e.g. "
    "reflector constant (optional)\"},\"shape\":{\"type\":\"string\",\"enum\":[\"circ"
    "ular_disk\"],\"description\":\"shape "
    "identifier\"}},\"required\":[\"shape\",\"diameter\"],\"description\":\"circular "
    "disk specific properties\"}],\"description\":\"circular disk\"},\"sphere\":{\""
    "type\":\"object\",\"allOf\":[{\"$ref\":\"#/definitions/common\"},{\"type\":\"objec"
    "t\",\"properties\":{\"diameter\":{\"type\":\"number\",\"minimum\":0,\"description\""
    ":\"diameter in meters\",\"exclusiveMinimum\":true},\"shape\":{\"type\":\"string"
    "\",\"enum\":[\"sphere\"],\"description\":\"shape "
    "identifier\"}},\"required\":[\"shape\",\"diameter\"],\"description\":\"sphere "
    "specific properties\"}],\"description\":\"sphere\"},\"cylinder\":{\"type\":\"obj"
    "ect\",\"allOf\":[{\"$ref\":\"#/definitions/common\"},{\"type\":\"object\",\"proper"
    "ties\":{\"diameter\":{\"type\":\"number\",\"minimum\":0,\"description\":\"diameter"
    " in meters\",\"exclusiveMinimum\":true},\"shape\":{\"type\":\"string\",\"enum\":["
    "\"cylinder\"],\"description\":\"shape identifier\"},\"height\":{\"type\":\"number"
    "\",\"minimum\":0,\"description\":\"height in meters\",\"exclusiveMinimum\":true"
    "}},\"required\":[\"shape\",\"diameter\",\"height\"],\"description\":\"cylinder "
    "specific properties\"}],\"description\":\"cylinder\"},\"chevron\":{\"type\":\"ob"
    "ject\",\"allOf\":[{\"$ref\":\"#/definitions/common\"},{\"type\":\"object\",\"prope"
    "rties\":{\"thickness\":{\"type\":\"number\",\"minimum\":0,\"description\":\"thickn"
    "ess in meters\",\"exclusiveMinimum\":true},\"shape\":{\"type\":\"string\",\"enum"
    "\":[\"chevron\"],\"description\":\"shape identifier\"},\"outside_edge_length\":"
    "{\"type\":\"number\",\"minimum\":0,\"description\":\"length of the two outer "
    "edges in meters\",\"exclusiveMinimum\":true}},\"required\":[\"shape\",\"outsid"
    "e_edge_length\",\"thickness\"],\"description\":\"chevron specific properties"
    "\"}],\"description\":\"chevron\"},\"rectangle\":{\"type\":\"object\",\"allOf\":[{\"$"
    "ref\":\"#/definitions/common\"},{\"type\":\"object\",\"properties\":{\"width\":{\""
    "type\":\"number\",\"minimum\":0,\"description\":\"width in meters\",\"exclusiveM"
    "inimum\":true},\"shape\":{\"type\":\"string\",\"enum\":[\"rectangle\"]},\"length\":"
    "{\"type\":\"number\",\"minimum\":0,\"description\":\"length in meters\",\"exclusi"
    "veMinimum\":true}},\"required\":[\"shape\",\"length\",\"width\"],\"description\":"
    "\"rectangle specific properties\"}],\"description\":\"rectangle\"},\"round_co"
    "rner_cube_prism\":{\"type\":\"object\",\"allOf\":[{\"$ref\":\"#/definitions/comm"
    "on\"},{\"type\":\"object\",\"properties\":{\"diameter\":{\"type\":\"number\",\"minim"
    "um\":0,\"description\":\"diameter in meters\",\"exclusiveMinimum\":true},\"off"
    "set\":{\"type\":\"number\",\"description\":\"offset in meters, e.g. reflector "
    "constant (optional)\"},\"shape\":{\"type\":\"string\",\"enum\":[\"round_corner_c"
    "ube_prism\"],\"description\":\"shape "
    "identifier\"}},\"required\":[\"shape\",\"diameter\"],\"description\":\"round "
    "corner cube prism specific properties\"}],\"description\":\"round corner "
    "cube prism\"},\"common\":{\"type\":\"object\",\"properties\":{\"surface_type\":{\""
    "type\":\"string\",\"enum\":[\"retro_reflective_foil\",\"diffuse\"],\"description"
    "\":\"surface material type\"},\"shape\":{\"type\":\"string\",\"enum\":[\"rectangle"
    "\",\"checkerboard2x2\",\"chevron\",\"circular_disk\",\"cylinder\",\"sphere\",\"rou"
    "nd_corner_cube_prism\"],\"description\":\"shape "
    "identifier\"},\"name\":{\"type\":\"string\",\"description\":\"unique type identi"
    "fier\",\"minLength\":3},\"description\":{\"type\":\"string\",\"description\":\"str"
    "ing describing the "
    "object\"}},\"required\":[\"name\",\"shape\"],\"description\":\"common object "
    "properties\"}},\"required\":[\"types\"]}"
    ,
    /* example: */
    "{\"types\":[{\"width\":0.3,\"shape\":\"rectangle\",\"name\":\"Rectangle "
    "60x30\",\"length\":0.6,\"description\":\"Rectangle (60cm x "
    "30cm)\"},{\"width\":0.4,\"shape\":\"rectangle\",\"name\":\"Rectangle "
    "80x40\",\"length\":0.8,\"description\":\"Rectangle (80cm x 40cm)\"},{\"square_"
    "length\":0.3,\"shape\":\"checkerboard2x2\",\"name\":\"Checkerboard2x2 "
    "30\",\"description\":\"Checkerboard (square length: 30cm)\"},{\"square_lengt"
    "h\":0.5,\"shape\":\"checkerboard2x2\",\"name\":\"Checkerboard2x2 "
    "50\",\"description\":\"Checkerboard (square length: "
    "50cm)\"},{\"thickness\":0.1016,\"shape\":\"chevron\",\"name\":\"Chevron "
    "24''/4''\",\"outside_edge_length\":0.6096,\"description\":\"Chevron (a=24'';"
    " b=4'')\"},{\"diameter\":0.5,\"surface_type\":\"diffuse\",\"shape\":\"circular_d"
    "isk\",\"name\":\"Circular Disk 50\",\"description\":\" Circular Disk "
    "(diameter: 50cm)\"},{\"offset\":0.0,\"name\":\"RIEGL flat reflector 50 "
    "mm\",\"description\":\"flat circular reflector from retro-reflective foil\""
    ",\"diameter\":0.05,\"surface_type\":\"retro_reflective_foil\",\"shape\":\"circu"
    "lar_disk\"},{\"offset\":0.0,\"name\":\"RIEGL flat reflector 100 "
    "mm\",\"description\":\"flat circular reflector from retro-reflective foil\""
    ",\"diameter\":0.1,\"surface_type\":\"retro_reflective_foil\",\"shape\":\"circul"
    "ar_disk\"},{\"offset\":0.0,\"name\":\"RIEGL flat reflector 150 "
    "mm\",\"description\":\"flat circular reflector from retro-reflective foil\""
    ",\"diameter\":0.15,\"surface_type\":\"retro_reflective_foil\",\"shape\":\"circu"
    "lar_disk\"},{\"name\":\"RIEGL cylindrical reflector 50 "
    "mm\",\"description\":\"cylindrical reflector from retro-reflective foil\",\""
    "diameter\":0.05,\"surface_type\":\"retro_reflective_foil\",\"shape\":\"cylinde"
    "r\",\"height\":0.05},{\"name\":\"RIEGL cylindrical reflector 100 "
    "mm\",\"description\":\"cylindrical reflector from retro-reflective foil\",\""
    "diameter\":0.1,\"surface_type\":\"retro_reflective_foil\",\"shape\":\"cylinder"
    "\",\"height\":0.1},{\"diameter\":0.2,\"shape\":\"sphere\",\"name\":\"Sphere 200 "
    "mm\",\"description\":\"Sphere (diameter: 200 mm)\"},{\"diameter\":0.05,\"shape"
    "\":\"round_corner_cube_prism\",\"name\":\"Corner Cube Prism 50 "
    "mm\",\"offset\":0.0,\"description\":\"round corner cube "
    "prism\"}],\"comments\":[\"This file contains a list of control object "
    "types (aka. 'catalog').\",\"Each type is described by an object,\",\"which"
    " must contain at least the following parameters:\",\"  - name: unique "
    "identifier of the type\",\"  - shape: one of the following supported "
    "shapes:\",\"      - rectangle\",\"      - checkerboard2x2\",\"      - "
    "chevron\",\"      - circular_disk\",\"      - cylinder\",\"      - sphere\",\""
    "      - round_corner_cube_prism\",\"Depending on 'shape', the following "
    "parameters must/may be specified:\",\"  - rectangle:\",\"      - length: "
    "length in meters\",\"      - width: width in meters\",\"  - "
    "checkerboard2x2:\",\"      - square_length: length of a square of the "
    "checkerboard in meters\",\"  - circular_disk:\",\"      - diameter: "
    "diameter in meters\",\"      - offset: offset in meters, e.g. reflector "
    "constant (optional)\",\"  - chevron:\",\"      - outside_edge_length: "
    "length of the two outer edges in meters\",\"      - thickness: thickness"
    " in meters\",\"  - cylinder:\",\"      - diameter: diameter in meters\",\""
    "      - height: height in meters\",\"  - sphere:\",\"      - diameter: "
    "diameter in meters\",\"  - round_corner_cube_prism:\",\"      - diameter: "
    "diameter in meters\",\"      - offset: offset in meters, e.g. reflector "
    "constant (optional)\",\"Optional parameters:\",\"    - description: string"
    " describing the object\",\"    - surface_type: surface material type "
    "(either 'retro_reflective_foil' or 'diffuse')\"]}"
};

// Details about the control object reference file
const MetaDataItemInfo RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE = {
    /* name        */ "riegl.control_object_reference_file",
    /* title       */ "Control Object Reference file",
    /* description */ "Details about the control object reference file",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"properties\":{\"reference_file\":{\"type\":\"object\",\"prop"
    "erties\":{\"file_uuid\":{\"type\":\"string\",\"description\":\"Control object "
    "file's Universally Unique Identifier (RFC "
    "4122)\"},\"file_path\":{\"type\":\"string\",\"description\":\"Path of the "
    "control object file relative to referring "
    "file\"}},\"required\":[\"file_uuid\",\"file_path\"],\"description\":\"Reference "
    "to a control object file\"}},\"title\":\"Control Object Reference file\",\"$"
    "schema\":\"http://json-schema.org/draft-04/schema#\",\"description\":\"Detai"
    "ls about the control object reference file\"}"
    ,
    /* example: */
    "{\"reference_file\":{\"file_uuid\":\"810f5d57-eccf-49ed-b07a-0cdd109b4213\","
    "\"file_path\":\"../../../10_CONTROL_OBJECTS/ControlPoints.cpx\"}}"
};

// Detection probability as a function of amplitude
const MetaDataItemInfo RDB_RIEGL_DETECTION_PROBABILITY = {
    /* name        */ "riegl.detection_probability",
    /* title       */ "Detection Probability",
    /* description */ "Detection probability as a function of amplitude",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"properties\":{\"detection_probability\":{\"type\":\"array\""
    ",\"items\":{\"type\":\"number\"},\"description\":\"Detection probability [0..1]"
    "\"},\"amplitude\":{\"type\":\"array\",\"items\":{\"type\":\"number\"},\"description\""
    ":\"Amplitude [dB]\"}},\"title\":\"Detection Probability\",\"$schema\":\"http://"
    "json-schema.org/draft-04/schema#\",\"description\":\"Detection probability"
    " as a function of "
    "amplitude\",\"required\":[\"amplitude\",\"detection_probability\"]}"
    ,
    /* example: */
    "{\"detection_probability\":[0.0,0.5,0.8,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0]"
    ",\"amplitude\":[0.0,1.0,2.0,3.0,4.0,5.0,6.0,7.0,8.0,9.0,10.0]}"
};

// Details about the device used to acquire the point cloud
const MetaDataItemInfo RDB_RIEGL_DEVICE = {
    /* name        */ "riegl.device",
    /* title       */ "Device Information",
    /* description */ "Details about the device used to acquire the point cloud",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"properties\":{\"channel_number\":{\"type\":\"integer\",\"min"
    "imum\":0,\"description\":\"Laser channel number (not defined or 0: single "
    "channel device)\",\"exclusiveMinimum\":false},\"device_type\":{\"type\":\"stri"
    "ng\",\"description\":\"Device type identifier (e.g. "
    "VZ-400i)\"},\"channel_text\":{\"type\":\"string\",\"description\":\"Optional "
    "channel description (e.g. 'Green Channel' for multi-channel "
    "devices)\"},\"serial_number\":{\"type\":\"string\",\"description\":\"Device "
    "serial number (e.g. "
    "S2221234)\"},\"device_name\":{\"type\":\"string\",\"description\":\"Optional "
    "device name (e.g. 'Scanner 1' for multi-scanner "
    "systems)\"},\"device_build\":{\"type\":\"string\",\"description\":\"Device build"
    " variant\"}},\"title\":\"Device Information\",\"$schema\":\"http://json-schema"
    ".org/draft-04/schema#\",\"description\":\"Details about the device used to"
    " acquire the point cloud\",\"required\":[\"device_type\",\"serial_number\"]}"
    ,
    /* example: */
    "{\"channel_number\":0,\"device_type\":\"VZ-400i\",\"channel_text\":\"\",\"serial_"
    "number\":\"S2221234\",\"device_name\":\"Scanner 1\",\"device_build\":\"\"}"
};

// Scanner device geometry details
const MetaDataItemInfo RDB_RIEGL_DEVICE_GEOMETRY = {
    /* name        */ "riegl.device_geometry",
    /* title       */ "Device Geometry",
    /* description */ "Scanner device geometry details",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"properties\":{\"secondary\":{\"type\":\"object\",\"propertie"
    "s\":{\"content\":{\"type\":\"array\",\"items\":{\"type\":\"number\"},\"description\":"
    "\"Internal calibration values\"},\"ID\":{\"type\":\"array\",\"minItems\":2,\"maxI"
    "tems\":2,\"items\":{\"type\":\"integer\"},\"description\":\"Structure "
    "identifier\"}},\"required\":[\"ID\",\"content\"],\"description\":\"Additional "
    "device geometry structure (optional)\"},\"primary\":{\"type\":\"object\",\"pro"
    "perties\":{\"content\":{\"type\":\"array\",\"items\":{\"type\":\"number\"},\"descrip"
    "tion\":\"Internal calibration values\"},\"ID\":{\"type\":\"array\",\"minItems\":2"
    ",\"maxItems\":2,\"items\":{\"type\":\"integer\"},\"description\":\"Structure "
    "identifier\"}},\"required\":[\"ID\",\"content\"],\"description\":\"Primary "
    "device geometry structure (mandatory)\"},\"amu\":{\"type\":\"object\",\"proper"
    "ties\":{\"lineCC\":{\"type\":\"number\",\"minimum\":0,\"description\":\"Line "
    "Circle Count (number of LSBs per full rotation about line axis)\",\"excl"
    "usiveMinimum\":false},\"frameCC\":{\"type\":\"number\",\"minimum\":0,\"descripti"
    "on\":\"Frame Circle Count (number of LSBs per full rotation about frame "
    "axis)\",\"exclusiveMinimum\":false}},\"description\":\"Angle Measurement "
    "Unit\"}},\"title\":\"Device Geometry\",\"$schema\":\"http://json-schema.org/dr"
    "aft-04/schema#\",\"description\":\"Scanner device geometry "
    "details\",\"required\":[\"primary\"]}"
    ,
    /* example: */
    "{\"secondary\":{\"content\":[0],\"ID\":[91,0]},\"primary\":{\"content\":[0],\"ID\""
    ":[4,0]},\"amu\":{\"lineCC\":124000,\"frameCC\":124000}}"
};

// Scanner passive channel device geometry details
const MetaDataItemInfo RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL = {
    /* name        */ "riegl.device_geometry_passive_channel",
    /* title       */ "Device Geometry Passive Channel",
    /* description */ "Scanner passive channel device geometry details",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"properties\":{\"primary\":{\"type\":\"object\",\"properties\""
    ":{\"content\":{\"type\":\"array\",\"items\":{\"type\":\"number\"},\"description\":\"I"
    "nternal calibration values\"},\"ID\":{\"type\":\"array\",\"minItems\":2,\"maxIte"
    "ms\":2,\"items\":{\"type\":\"integer\"},\"description\":\"Structure "
    "identifier\"}},\"required\":[\"ID\",\"content\"],\"description\":\"Primary "
    "device geometry structure (mandatory)\"}},\"title\":\"Device Geometry "
    "Passive Channel\",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\""
    "description\":\"Scanner passive channel device geometry "
    "details\",\"required\":[\"primary\"]}"
    ,
    /* example: */
    "{\"primary\":{\"content\":[0],\"ID\":[143,0]}}"
};

// Limits of the measured values output by the device
const MetaDataItemInfo RDB_RIEGL_DEVICE_OUTPUT_LIMITS = {
    /* name        */ "riegl.device_output_limits",
    /* title       */ "Device Output Limits",
    /* description */ "Limits of the measured values output by the device",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"properties\":{\"echo_count_maximum\":{\"type\":\"number\",\""
    "description\":\"Maximum number of echoes a laser shot can have.\"},\"backg"
    "round_radiation_maximum\":{\"type\":\"number\",\"description\":\"Maximum "
    "possible background "
    "radiation.\"},\"range_maximum\":{\"type\":\"number\",\"description\":\"Maximum "
    "possible range in "
    "meters.\"},\"deviation_minimum\":{\"type\":\"number\",\"description\":\"Minimum "
    "possible pulse shape deviation.\"},\"reflectance_minimum\":{\"type\":\"numbe"
    "r\",\"description\":\"Minimum possible reflectance in "
    "dB.\"},\"reflectance_maximum\":{\"type\":\"number\",\"description\":\"Maximum "
    "possible reflectance in "
    "dB.\"},\"amplitude_maximum\":{\"type\":\"number\",\"description\":\"Maximum "
    "possible amplitude in "
    "dB.\"},\"mta_zone_count_maximum\":{\"type\":\"number\",\"description\":\"Maximum"
    " number of MTA "
    "zones.\"},\"deviation_maximum\":{\"type\":\"number\",\"description\":\"Maximum "
    "possible pulse shape deviation.\"},\"amplitude_minimum\":{\"type\":\"number\""
    ",\"description\":\"Minimum possible amplitude in "
    "dB.\"},\"range_minimum\":{\"type\":\"number\",\"description\":\"Minimum possible"
    " range in meters.\"},\"background_radiation_minimum\":{\"type\":\"number\",\"d"
    "escription\":\"Minimum possible background radiation.\"}},\"title\":\"Device"
    " Output Limits\",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"d"
    "escription\":\"Limits of the measured values output by the device. The "
    "limits depend on the device type, measurement program and/or scan "
    "pattern.\"}"
    ,
    /* example: */
    "{\"reflectance_maximum\":100.0,\"deviation_minimum\":-1,\"range_minimum\":2."
    "9,\"mta_zone_count_maximum\":7,\"range_maximum\":10000.0,\"background_radia"
    "tion_maximum\":0,\"reflectance_minimum\":-100.0,\"amplitude_minimum\":0.0,\""
    "background_radiation_minimum\":0,\"amplitude_maximum\":100.0,\"deviation_m"
    "aximum\":32767}"
};

// Details about the devices used to acquire the point cloud
const MetaDataItemInfo RDB_RIEGL_DEVICES = {
    /* name        */ "riegl.devices",
    /* title       */ "Devices Information",
    /* description */ "Details about the devices used to acquire the point cloud",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"array\",\"title\":\"Devices Information\",\"$schema\":\"http://json-s"
    "chema.org/draft-04/schema#\",\"items\":{\"type\":\"object\",\"properties\":{\"ch"
    "annel_number\":{\"type\":\"integer\",\"minimum\":0,\"description\":\"Laser "
    "channel number (not defined or 0: single channel device)\",\"exclusiveMi"
    "nimum\":false},\"device_type\":{\"type\":\"string\",\"description\":\"Device "
    "type identifier (e.g. "
    "VZ-400i)\"},\"channel_text\":{\"type\":\"string\",\"description\":\"Optional "
    "channel description (e.g. 'Green Channel' for multi-channel "
    "devices)\"},\"serial_number\":{\"type\":\"string\",\"description\":\"Device "
    "serial number (e.g. "
    "S2221234)\"},\"signed\":{\"type\":\"boolean\",\"description\":\"Flag that is set"
    " when the original 'riegl.device' entry in the source file was "
    "correctly "
    "signed.\"},\"device_name\":{\"type\":\"string\",\"description\":\"Optional "
    "device name (e.g. 'Scanner 1' for multi-scanner "
    "systems)\"},\"device_build\":{\"type\":\"string\",\"description\":\"Device build"
    " variant\"}},\"required\":[\"device_type\",\"serial_number\"]},\"description\":"
    "\"Details about the devices used to acquire the point cloud (e.g. when "
    "merging point clouds of different devices)\"}"
    ,
    /* example: */
    "[{\"channel_number\":0,\"device_type\":\"VZ-400i\",\"channel_text\":\"\",\"serial"
    "_number\":\"S2221234\",\"signed\":false,\"device_name\":\"Scanner 1\",\"device_b"
    "uild\":\"\"},{\"channel_number\":1,\"device_type\":\"VQ-1560i-DW\",\"channel_tex"
    "t\":\"\",\"serial_number\":\"S2222680\",\"signed\":true,\"device_name\":\"Scanner "
    "2\",\"device_build\":\"\"},{\"channel_number\":2,\"device_type\":\"VQ-1560i-DW\","
    "\"channel_text\":\"\",\"serial_number\":\"S2222680\",\"signed\":true,\"device_nam"
    "e\":\"Scanner 3\",\"device_build\":\"\"}]"
};

// Dyntrig
const MetaDataItemInfo RDB_RIEGL_DYNTRIG = {
    /* name        */ "riegl.dyntrig",
    /* title       */ "Dyntrig",
    /* description */ "Dyntrig",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"post\":{\"type\":\"object\",\"properties\":{\"nc\":{\"type\":\"int"
    "eger\",\"maximum\":255,\"minimum\":0,\"description\":\"Number of entries\"},\"a\""
    ":{\"type\":\"array\",\"minItems\":1,\"maxItems\":2080,\"items\":{\"type\":\"number\""
    "},\"description\":\"...\"}},\"required\":[\"nc\",\"a\"],\"description\":\"Dyntrig "
    "post values\"},\"offset\":{\"type\":\"number\",\"description\":\"Offset in units"
    " of dB, for calculation of line\"},\"tab\":{\"type\":\"array\",\"minItems\":1,\""
    "maxItems\":128,\"items\":{\"type\":\"object\",\"properties\":{\"thra2\":{\"type\":\""
    "number\",\"description\":\"Pre-trigger threshold in units of "
    "dB\"},\"dec2\":{\"type\":\"number\",\"description\":\"Rise of pre-trigger "
    "threshold after del2 in units of "
    "dB/m\"},\"del2\":{\"type\":\"number\",\"description\":\"Length of constant "
    "pre-trigger threshold elevation in units of "
    "m\"},\"thra1\":{\"type\":\"number\",\"description\":\"Post-trigger threshold in "
    "units of dB\"},\"dec1\":{\"type\":\"number\",\"description\":\"Decay of "
    "post-trigger threshold after del1 in units of "
    "dB/m\"},\"del1\":{\"type\":\"number\",\"description\":\"Length of constant "
    "post-trigger threshold elevation in units of m\"}},\"required\":[\"thra1\","
    "\"del1\",\"dec1\",\"thra2\",\"del2\",\"dec2\"],\"description\":\"...\"},\"description"
    "\":\"...\"},\"pre\":{\"type\":\"object\",\"properties\":{\"nc\":{\"type\":\"integer\",\""
    "maximum\":255,\"minimum\":0,\"description\":\"Number of entries\"},\"a\":{\"type"
    "\":\"array\",\"minItems\":1,\"maxItems\":2080,\"items\":{\"type\":\"number\"},\"desc"
    "ription\":\"...\"}},\"required\":[\"nc\",\"a\"],\"description\":\"Dyntrig pre "
    "values\"},\"scale\":{\"type\":\"number\",\"description\":\"Scale in units of dB,"
    " for calculation of line: line number N=(amplitude-offset)/scale\"}},\"t"
    "itle\":\"Dyntrig\",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"d"
    "escription\":\"Dyntrig\"}"
    ,
    /* example: */
    "{\"post\":{\"nc\":128,\"a\":[78,86,126,134,31]},\"offset\":0.0,\"tab\":[{\"thra2\""
    ":0.0,\"dec2\":0.0,\"del2\":0.0,\"thra1\":0.0,\"dec1\":0.0,\"del1\":0.0}],\"pre\":{"
    "\"nc\":128,\"a\":[78,86,126,134,31]},\"scale\":1.0}"
};

// Details about echo files
const MetaDataItemInfo RDB_RIEGL_ECHO_INFO = {
    /* name        */ "riegl.echo_info",
    /* title       */ "Echo Information",
    /* description */ "Details about echo files",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"properties\":{\"echo_file\":{\"type\":\"object\",\"propertie"
    "s\":{\"file_uuid\":{\"type\":\"string\",\"description\":\"File's Universally "
    "Unique Identifier (RFC "
    "4122)\"},\"file_extension\":{\"type\":\"string\",\"description\":\"Echo file "
    "extension, without the leading "
    "dot\"}},\"required\":[\"file_extension\"]}},\"title\":\"Echo Information\",\"$sc"
    "hema\":\"http://json-schema.org/draft-04/schema#\",\"description\":\"Details"
    " about echo files\",\"required\":[\"echo_file\"]}"
    ,
    /* example: */
    "{\"echo_file\":{\"file_uuid\":\"26a03615-67c0-4bea-8fe8-c577378fe661\",\"file"
    "_extension\":\"owp\"}}"
};

// Details for exponential decomposition of full waveform data
const MetaDataItemInfo RDB_RIEGL_EXPONENTIAL_DECOMPOSITION = {
    /* name        */ "riegl.exponential_decomposition",
    /* title       */ "Exponential Decomposition",
    /* description */ "Details for exponential decomposition of full waveform data",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"title\":\"Exponential Decomposition\",\"$schema\":\"http:/"
    "/json-schema.org/draft-04/schema#\",\"patternProperties\":{\"^[0-9]+$\":{\"d"
    "escription\":\"one field per channel, field name is channel "
    "index\",\"$ref\":\"#/definitions/channel\"}},\"description\":\"Details for "
    "exponential decomposition of full waveform data\",\"definitions\":{\"chann"
    "el\":{\"type\":\"object\",\"properties\":{\"a_lin\":{\"type\":\"number\",\"exclusive"
    "Minimum\":false,\"description\":\"relative linear amplitude range [0..1]\","
    "\"maximum\":1,\"minimum\":0,\"exclusiveMaximum\":false},\"parameter\":{\"type\":"
    "\"object\",\"properties\":{\"gamma\":{\"type\":\"array\",\"items\":{\"type\":\"number"
    "\"},\"description\":\"decay in 1/second\"},\"A\":{\"type\":\"array\",\"items\":{\"ty"
    "pe\":\"number\"},\"description\":\"real part of amplitude factor in units of"
    " full-scale\"},\"B\":{\"type\":\"array\",\"items\":{\"type\":\"number\"},\"descripti"
    "on\":\"imaginary part of amplitude factor in units of full-scale\"},\"omeg"
    "a\":{\"type\":\"array\",\"items\":{\"type\":\"number\"},\"description\":\"angular "
    "frequency in "
    "Hz\"}},\"required\":[\"A\",\"B\",\"gamma\",\"omega\"],\"description\":\"parameters "
    "of the syswave exponential "
    "sum\"},\"delay\":{\"type\":\"number\",\"description\":\"delay calibration in "
    "seconds\"},\"scale\":{\"type\":\"number\",\"description\":\"amplitude calibratio"
    "n\"}},\"required\":[\"delay\",\"scale\",\"parameter\"]}},\"additionalProperties\""
    ":false}"
    ,
    /* example: */
    "{\"0\":{\"a_lin\":0.27,\"parameter\":{\"gamma\":[-1094726528.0,-769562752.0,-8"
    "48000064.0],\"A\":[0.9772450923919678,0.3354335129261017,-1.312678575515"
    "747],\"B\":[-3.9813032150268555,0.08622030913829803,-0.3152860999107361]"
    ",\"omega\":[352020896.0,3647927552.0,-1977987072.0]},\"delay\":3.783458418"
    "887631e-09,\"scale\":1.0},\"1\":{\"a_lin\":0.9,\"parameter\":{\"gamma\":[-109472"
    "6528.0,-769562752.0,-848000064.0],\"A\":[0.9,0.3,-1.3],\"B\":[-3.9,0.0,-0."
    "3],\"omega\":[352020896.0,3647927552.0,-1977987072.0]},\"delay\":3.5e-09,\""
    "scale\":1.0}}"
};

// Details for Gaussian decomposition of full waveform data
const MetaDataItemInfo RDB_RIEGL_GAUSSIAN_DECOMPOSITION = {
    /* name        */ "riegl.gaussian_decomposition",
    /* title       */ "Gaussian Decomposition",
    /* description */ "Details for Gaussian decomposition of full waveform data",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"properties\":{\"range_offset_sec_high_power\":{\"type\":\""
    "array\",\"items\":{\"type\":\"number\"}},\"amplitude_lsb_high_power\":{\"type\":\""
    "array\",\"items\":{\"type\":\"number\"}},\"amplitude_lsb_low_power\":{\"type\":\"a"
    "rray\",\"items\":{\"type\":\"number\"}},\"range_offset_sec_low_power\":{\"type\":"
    "\"array\",\"items\":{\"type\":\"number\"}},\"amplitude_db\":{\"type\":\"array\",\"ite"
    "ms\":{\"type\":\"number\"}}},\"title\":\"Gaussian Decomposition\",\"$schema\":\"ht"
    "tp://json-schema.org/draft-04/schema#\",\"description\":\"riegl.gaussian_d"
    "ecomposition contains information relevant for extracting calibrated "
    "amplitudes and calibrated ranges from a Gaussian decomposition of full"
    " waveform data. This information is contained in a table with five "
    "columns. Two columns are to be used as input: amplitude_lsb_low_power "
    "and amplitude_lsb_high_power. The other three columns provide the "
    "outputs. Amplitude_db gives the calibrated amplitude in the optical "
    "regime in decibels. The range offset columns provide additive range "
    "offsets, given in units of seconds, for each channel.\",\"required\":[\"am"
    "plitude_lsb_low_power\",\"amplitude_lsb_high_power\",\"amplitude_db\",\"rang"
    "e_offset_sec_low_power\",\"range_offset_sec_high_power\"]}"
    ,
    /* example: */
    "{\"range_offset_sec_high_power\":[],\"amplitude_lsb_high_power\":[],\"ampli"
    "tude_lsb_low_power\":[],\"range_offset_sec_low_power\":[],\"amplitude_db\":"
    "[]}"
};

// Point cloud georeferencing information
const MetaDataItemInfo RDB_RIEGL_GEO_TAG = {
    /* name        */ "riegl.geo_tag",
    /* title       */ "Geo Tag",
    /* description */ "Point cloud georeferencing information",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"properties\":{\"pose\":{\"type\":\"array\",\"maxItems\":4,\"mi"
    "nItems\":4,\"items\":{\"type\":\"array\",\"maxItems\":4,\"minItems\":4,\"items\":{\""
    "type\":\"number\",\"description\":\"columns\"},\"description\":\"rows\"},\"descrip"
    "tion\":\"Coordinate Transformation Matrix to transform from File "
    "Coordinate System to Global Coordinate Reference System. 4x4 matrix "
    "stored as two dimensional array, row major order.\"},\"crs\":{\"type\":\"obj"
    "ect\",\"properties\":{\"epsg\":{\"type\":\"integer\",\"minimum\":0,\"description\":"
    "\"EPSG code\"},\"wkt\":{\"type\":\"string\",\"description\":\"\\\"Well-Known Text\\\""
    " string, OGC WKT dialect (see http://www.opengeospatial.org/standards/"
    "wkt-crs)\"},\"name\":{\"type\":\"string\",\"description\":\"Coordinate reference"
    " system name\"}},\"description\":\"Global Coordinate Reference System. "
    "Please note that only 3D Cartesian Coordinate Systems are "
    "allowed.\"}},\"title\":\"Geo Tag\",\"$schema\":\"http://json-schema.org/draft-"
    "04/schema#\",\"description\":\"Point cloud georeferencing information\"}"
    ,
    /* example: */
    "{\"pose\":[[-0.269827776749716,-0.723017716139738,0.635954678449952,4063"
    "882.500831],[0.962908599449764,-0.20260517250352,0.178208229833847,113"
    "8787.607461],[0.0,0.660451759194338,0.7508684796801,4766084.550196],[0"
    ".0,0.0,0.0,1.0]],\"crs\":{\"epsg\":4978,\"wkt\":\"GEOCCS[\\\"WGS84 Geocentric\\\""
    ",DATUM[\\\"WGS84\\\",SPHEROID[\\\"WGS84\\\",6378137.000,298.257223563,AUTHORIT"
    "Y[\\\"EPSG\\\",\\\"7030\\\"]],AUTHORITY[\\\"EPSG\\\",\\\"6326\\\"]],PRIMEM[\\\"Greenwich"
    "\\\",0.0000000000000000,AUTHORITY[\\\"EPSG\\\",\\\"8901\\\"]],UNIT[\\\"Meter\\\",1.0"
    "0000000000000000000,AUTHORITY[\\\"EPSG\\\",\\\"9001\\\"]],AXIS[\\\"X\\\",OTHER],AX"
    "IS[\\\"Y\\\",EAST],AXIS[\\\"Z\\\",NORTH],AUTHORITY[\\\"EPSG\\\",\\\"4978\\\"]]\",\"name\""
    ":\"WGS84 Geocentric\"}}"
};

// Geometric scale factor applied to point coordinates
const MetaDataItemInfo RDB_RIEGL_GEOMETRIC_SCALE_FACTOR = {
    /* name        */ "riegl.geometric_scale_factor",
    /* title       */ "Geometric Scale Factor",
    /* description */ "Geometric scale factor applied to point coordinates",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"number\",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\""
    "minimum\":0,\"description\":\"Geometric scale factor applied to point "
    "coordinates\",\"exclusiveMinimum\":true}"
    ,
    /* example: */
    "1.0"
};

// Parameters used for georeferencing of the point cloud
const MetaDataItemInfo RDB_RIEGL_GEOREFERENCING_PARAMETERS = {
    /* name        */ "riegl.georeferencing_parameters",
    /* title       */ "Georeferencing Parameters",
    /* description */ "Parameters used for georeferencing of the point cloud",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"properties\":{\"socs_to_body_matrix\":{\"type\":\"array\",\""
    "maxItems\":4,\"minItems\":4,\"items\":{\"type\":\"array\",\"maxItems\":4,\"minItem"
    "s\":4,\"items\":{\"type\":\"number\",\"description\":\"columns\"},\"description\":\""
    "rows\"},\"description\":\"Coordinate Transformation Matrix to transform "
    "from Scanner's Own Coordinate System to Body Coordinate System. 4x4 "
    "matrix stored as two dimensional array, row major order.\"},\"trajectory"
    "_file\":{\"type\":\"object\",\"properties\":{\"file_uuid\":{\"type\":\"string\",\"de"
    "scription\":\"File's Universally Unique Identifier (RFC "
    "4122)\"},\"file_extension\":{\"type\":\"string\",\"description\":\"Trajectory "
    "file extension, without the leading "
    "dot\"}},\"required\":[\"file_extension\"],\"description\":\"Trajectory data "
    "used for georeferencing of the point cloud\"},\"socs_to_rocs_matrix\":{\"t"
    "ype\":\"array\",\"maxItems\":4,\"minItems\":4,\"items\":{\"type\":\"array\",\"maxIte"
    "ms\":4,\"minItems\":4,\"items\":{\"type\":\"number\",\"description\":\"columns\"},\""
    "description\":\"rows\"},\"description\":\"Coordinate Transformation Matrix "
    "to transform from Scanner's Own Coordinate System to Record Coordinate"
    " System. 4x4 matrix stored as two dimensional array, row major order.\""
    "},\"body_coordinate_system_type\":{\"type\":\"string\",\"enum\":[\"NED\",\"ENU\"],"
    "\"description\":\"BODY coordinate frame (NED: North-East-Down, ENU: "
    "East-North-Up), default: NED\"},\"trajectory_offsets\":{\"type\":\"object\",\""
    "properties\":{\"offset_pitch\":{\"type\":\"number\",\"description\":\"[deg]\"},\"o"
    "ffset_yaw\":{\"type\":\"number\",\"description\":\"[deg]\"},\"offset_time\":{\"typ"
    "e\":\"number\",\"description\":\"[s]\"},\"offset_roll\":{\"type\":\"number\",\"descr"
    "iption\":\"[deg]\"},\"offset_north\":{\"type\":\"number\",\"description\":\"[m]\"},"
    "\"offset_east\":{\"type\":\"number\",\"description\":\"[m]\"},\"version\":{\"type\":"
    "\"integer\",\"description\":\"Meaning of offset values and how to apply "
    "them; version 0: "
    "Rz(yaw+offset_yaw)*Ry(pitch+offset_pitch)*Rx(roll+offset_roll), "
    "version 1: Rz(yaw)*Ry(pitch)*Rx(roll) * Rz(offset_yaw)*Ry(offset_pitch"
    ")*Rx(offset_roll)\"},\"offset_height\":{\"type\":\"number\",\"description\":\"[m"
    "]\"}},\"description\":\"Correction offsets applied to the trajectory "
    "data\"}},\"title\":\"Georeferencing Parameters\",\"$schema\":\"http://json-sch"
    "ema.org/draft-04/schema#\",\"description\":\"Parameters used for "
    "georeferencing of the point cloud\"}"
    ,
    /* example: */
    "{\"socs_to_body_matrix\":[[-0.269827776749716,-0.723017716139738,0.63595"
    "4678449952,0.0],[0.962908599449764,-0.20260517250352,0.178208229833847"
    ",0.0],[0.0,0.660451759194338,0.7508684796801,0.0],[0.0,0.0,0.0,1.0]],\""
    "trajectory_file\":{\"file_uuid\":\"93a03615-66c0-4bea-8ff8-c577378fe660\",\""
    "file_extension\":\"pofx\"},\"body_coordinate_system_type\":\"NED\",\"trajector"
    "y_offsets\":{\"offset_pitch\":0.01,\"offset_yaw\":-0.45,\"offset_time\":18.00"
    "7,\"offset_roll\":0.03,\"offset_north\":0.07,\"offset_east\":0.15,\"version\":"
    "0,\"offset_height\":-0.2}}"
};

// Map of item names
const MetaDataItemInfo RDB_RIEGL_ITEM_NAMES = {
    /* name        */ "riegl.item_names",
    /* title       */ "Item Names",
    /* description */ "Map of item names",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"title\":\"Item Names\",\"$schema\":\"http://json-schema.or"
    "g/draft-04/schema#\",\"patternProperties\":{\"^-?[0-9]+$\":{\"type\":\"string\""
    ",\"description\":\"One field per item, field name is item id, field value"
    " is item name\"}},\"description\":\"Map of item "
    "names\",\"additionalProperties\":false}"
    ,
    /* example: */
    "{\"2\":\"Name of item with id 2\",\"1\":\"Name of item with id 1\",\"47\":\"Name "
    "of item with id 47\",\"-1\":\"Name of item with id -1\"}"
};

// License keys for software features
const MetaDataItemInfo RDB_RIEGL_LICENSES = {
    /* name        */ "riegl.licenses",
    /* title       */ "Software License Keys",
    /* description */ "License keys for software features",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"title\":\"Software License Keys\",\"$schema\":\"http://jso"
    "n-schema.org/draft-04/schema#\",\"patternProperties\":{\"^.*$\":{\"type\":\"ar"
    "ray\",\"minItems\":1,\"items\":{\"type\":\"string\",\"description\":\"License key "
    "(example: '46AE032A - 39882AC4 - 9EC0A184 - "
    "6F163D73')\"},\"description\":\"Each field of the object represents a "
    "feature and holds a list of license keys, where the field name is the "
    "feature name.\"}},\"description\":\"License keys for software "
    "features\",\"additionalProperties\":false}"
    ,
    /* example: */
    "{\"Full Waveform Analysis Topography\":[\"0FD5FF07 - 011A1255 - 9F76CACA "
    "- 8D2ED557\"],\"MTA resolution\":[\"468E020A - 39A922E4 - B681A184 - "
    "673E3D72\"],\"Georeferencing\":[\"46AE032A - 39882AC4 - 9EC0A184 - "
    "6F163D73\"],\"Full Waveform Analysis Topography with GPU "
    "support\":[\"8AB44126 - 23B92250 - 16E2689F - 34EF7E7B\"]}"
};

// Parameters for MTA processing
const MetaDataItemInfo RDB_RIEGL_MTA_SETTINGS = {
    /* name        */ "riegl.mta_settings",
    /* title       */ "MTA Settings",
    /* description */ "Parameters for MTA processing",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"properties\":{\"modulation_depth\":{\"type\":\"number\",\"mi"
    "nimum\":0,\"description\":\"Depth of pulse position modulation in meter.\"}"
    ",\"zone_width\":{\"type\":\"number\",\"minimum\":0,\"description\":\"Width of a "
    "MTA zone in meter.\"},\"zone_count\":{\"type\":\"integer\",\"maximum\":255,\"min"
    "imum\":0,\"description\":\"Maximum number of MTA zones.\"}},\"title\":\"MTA Se"
    "ttings\",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"descripti"
    "on\":\"Parameters for MTA processing\"}"
    ,
    /* example: */
    "{\"modulation_depth\":9.368514,\"zone_width\":149.896225,\"zone_count\":23}"
};

// Lookup table for range correction based on raw range
const MetaDataItemInfo RDB_RIEGL_NEAR_RANGE_CORRECTION = {
    /* name        */ "riegl.near_range_correction",
    /* title       */ "Near Range Correction Table",
    /* description */ "Lookup table for range correction based on raw range",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"properties\":{\"content\":{\"type\":\"array\",\"minItems\":1,"
    "\"maxItems\":2000,\"items\":{\"type\":\"number\"},\"description\":\"Correction "
    "value [m] to be added to the raw "
    "range\"},\"delta\":{\"type\":\"number\",\"description\":\"Delta between table "
    "entries [m], first entry is at range = 0 m\"}},\"title\":\"Near Range "
    "Correction Table\",\"$schema\":\"http://json-schema.org/draft-04/schema#\","
    "\"description\":\"Lookup table for range correction based on raw "
    "range\",\"required\":[\"delta\",\"content\"]}"
    ,
    /* example: */
    "{\"content\":[0.0],\"delta\":0.512}"
};

// Standard deviation for range and amplitude as a function of amplitude
const MetaDataItemInfo RDB_RIEGL_NOISE_ESTIMATES = {
    /* name        */ "riegl.noise_estimates",
    /* title       */ "Noise Estimates",
    /* description */ "Standard deviation for range and amplitude as a function of amplitude",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"properties\":{\"range_sigma\":{\"type\":\"array\",\"items\":{"
    "\"type\":\"number\"},\"description\":\"Sigma range [m]\"},\"amplitude_sigma\":{\""
    "type\":\"array\",\"items\":{\"type\":\"number\"},\"description\":\"Sigma amplitude"
    " [dB]\"},\"amplitude\":{\"type\":\"array\",\"items\":{\"type\":\"number\"},\"descrip"
    "tion\":\"Amplitude [dB]\"}},\"title\":\"Noise Estimates\",\"$schema\":\"http://j"
    "son-schema.org/draft-04/schema#\",\"description\":\"Standard deviation for"
    " range and amplitude as a function of "
    "amplitude\",\"required\":[\"amplitude\",\"range_sigma\",\"amplitude_sigma\"]}"
    ,
    /* example: */
    "{\"range_sigma\":[0.065,0.056,0.046,0.038,0.032,0.027,0.024,0.021,0.018,"
    "0.016,0.014],\"amplitude_sigma\":[0.988,0.988,0.875,0.774,0.686,0.608,0."
    "54,0.482,0.432,0.39,0.354],\"amplitude\":[0.0,1.0,2.0,3.0,4.0,5.0,6.0,7."
    "0,8.0,9.0,10.0]}"
};

// Notch filter parameters for window glass echoes
const MetaDataItemInfo RDB_RIEGL_NOTCH_FILTER = {
    /* name        */ "riegl.notch_filter",
    /* title       */ "Notch Filter",
    /* description */ "Notch filter parameters for window glass echoes",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"properties\":{\"range_maximum\":{\"type\":\"number\",\"descr"
    "iption\":\"Maximum range [m]\"},\"amplitude_maximum\":{\"type\":\"number\",\"min"
    "imum\":0,\"description\":\"Maximum amplitude "
    "[dB]\"},\"range_minimum\":{\"type\":\"number\",\"description\":\"Minimum range "
    "[m]\"}},\"title\":\"Notch Filter\",\"$schema\":\"http://json-schema.org/draft-"
    "04/schema#\",\"description\":\"Notch filter parameters for window glass ec"
    "hoes\",\"required\":[\"range_minimum\",\"range_maximum\",\"amplitude_maximum\"]"
    "}"
    ,
    /* example: */
    "{\"range_maximum\":0.2,\"amplitude_maximum\":18.0,\"range_minimum\":-0.5}"
};

// Details about the pixels contained in the file
const MetaDataItemInfo RDB_RIEGL_PIXEL_INFO = {
    /* name        */ "riegl.pixel_info",
    /* title       */ "Pixel Information",
    /* description */ "Details about the pixels contained in the file",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"properties\":{\"size\":{\"description\":\"Size of pixels "
    "in file coordinate system.\",\"$ref\":\"#/definitions/pixel_size\"},\"size_l"
    "lcs\":{\"description\":\"Size of pixels in a locally levelled cartesian "
    "coordinate system (xy). This is only used for pixels based on a map "
    "projection.\",\"$ref\":\"#/definitions/pixel_size\"}},\"title\":\"Pixel Inform"
    "ation\",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"descriptio"
    "n\":\"Details about the pixels contained in the file\",\"definitions\":{\"pi"
    "xel_size\":{\"type\":\"array\",\"maxItems\":2,\"minItems\":2,\"items\":{\"type\":\"n"
    "umber\",\"minimum\":0,\"description\":\"Length of pixel edge "
    "[m].\"},\"description\":\"Size of pixels.\"}},\"required\":[\"size\"]}"
    ,
    /* example: */
    "{\"size\":[0.5971642834779395,0.5971642834779395],\"size_llcs\":[0.5156575"
    "252891171,0.5130835356683303]}"
};

// Details about the plane patch matching process
const MetaDataItemInfo RDB_RIEGL_PLANE_PATCH_MATCHING = {
    /* name        */ "riegl.plane_patch_matching",
    /* title       */ "Plane Patch Matching",
    /* description */ "Details about the plane patch matching process",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"properties\":{\"plane_patch_file_one\":{\"description\":\""
    "Reference to the plane patch file one\",\"$ref\":\"#/definitions/file_refe"
    "rence\"},\"plane_patch_file_two\":{\"description\":\"Reference to the plane "
    "patch file two\",\"$ref\":\"#/definitions/file_reference\"}},\"title\":\"Plane"
    " Patch Matching\",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\""
    "description\":\"Details about the plane patch matching process\",\"definit"
    "ions\":{\"file_reference\":{\"type\":\"object\",\"properties\":{\"file_uuid\":{\"t"
    "ype\":\"string\",\"description\":\"Plane patch file's Universally Unique "
    "Identifier (RFC "
    "4122)\"},\"file_path\":{\"type\":\"string\",\"description\":\"Path of the plane "
    "patch file relative to the match "
    "file\"}},\"required\":[\"file_uuid\",\"file_path\"],\"description\":\"Reference "
    "to a plane patch "
    "file\"}},\"required\":[\"plane_patch_file_one\",\"plane_patch_file_two\"]}"
    ,
    /* example: */
    "{\"plane_patch_file_one\":{\"file_uuid\":\"810f5d57-eccf-49ed-b07a-0cdd109b"
    "4213\",\"file_path\":\"Record009_Line001/191025_121410_Scanner_1.ptch\"},\"p"
    "lane_patch_file_two\":{\"file_uuid\":\"fa47d509-a64e-49ce-8b14-ff3130fbefa"
    "9\",\"file_path\":\"project.ptch\"}}"
};

// Statistics about plane patches found by plane patch extractor
const MetaDataItemInfo RDB_RIEGL_PLANE_PATCH_STATISTICS = {
    /* name        */ "riegl.plane_patch_statistics",
    /* title       */ "Plane Patch Statistics",
    /* description */ "Statistics about plane patches found by plane patch extractor",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"properties\":{\"total_area\":{\"type\":\"number\",\"descript"
    "ion\":\"sum of all plane patch areas [m\\u00b2]\"},\"total_horizontal_area\""
    ":{\"type\":\"number\",\"description\":\"sum of all plane patch areas "
    "projected to horizontal plane [m\\u00b2]\"}},\"title\":\"Plane Patch Statis"
    "tics\",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"description"
    "\":\"Statistics about plane patches found by plane patch extractor\"}"
    ,
    /* example: */
    "{\"total_area\":14007.965,\"total_horizontal_area\":13954.601}"
};

// Settings and classes for plane slope classification
const MetaDataItemInfo RDB_RIEGL_PLANE_SLOPE_CLASS_INFO = {
    /* name        */ "riegl.plane_slope_class_info",
    /* title       */ "Plane Slope Class Info",
    /* description */ "Settings and classes for plane slope classification",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"properties\":{\"settings\":{\"type\":\"object\",\"descriptio"
    "n\":\"Classification settings, details see documentation of rdbplanes\",\""
    "oneOf\":[{\"$ref\":\"#/definitions/method-1\"},{\"$ref\":\"#/definitions/metho"
    "d-2\"}]},\"classes\":{\"type\":\"object\",\"additionalProperties\":false,\"patte"
    "rnProperties\":{\"^[0-9]+$\":{\"type\":\"string\",\"description\":\"one field "
    "per class, field name is class number, field value is class "
    "name\"}},\"description\":\"Class definition table\"}},\"title\":\"Plane Slope "
    "Class Info\",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"descr"
    "iption\":\"Settings and classes for plane slope classification\",\"definit"
    "ions\":{\"method-2\":{\"type\":\"object\",\"properties\":{\"sloping_plane_classe"
    "s_minimum_angle\":{\"type\":\"number\",\"maximum\":360.0,\"minimum\":-360.0,\"de"
    "scription\":\"minimum inclination angle of sloping plane patches [deg]\"}"
    ",\"sloping_plane_classes_maximum_angle\":{\"type\":\"number\",\"maximum\":360."
    "0,\"minimum\":-360.0,\"description\":\"maximum inclination angle of sloping"
    " plane patches [deg]\"},\"plane_classification_method\":{\"type\":\"integer\""
    ",\"maximum\":2,\"minimum\":2,\"description\":\"method ID (=2)\"}},\"required\":["
    "\"plane_classification_method\",\"sloping_plane_classes_minimum_angle\",\"s"
    "loping_plane_classes_maximum_angle\"],\"description\":\"Classification "
    "method 2\"},\"method-1\":{\"type\":\"object\",\"properties\":{\"maximum_inclinat"
    "ion_angle_horizontal\":{\"type\":\"number\",\"maximum\":360.0,\"minimum\":-360."
    "0,\"description\":\"maximum inclination angle of horizontal plane patches"
    " [deg]\"},\"plane_classification_method\":{\"type\":\"integer\",\"maximum\":1,\""
    "minimum\":1,\"description\":\"method ID (=1)\"}},\"required\":[\"plane_classif"
    "ication_method\",\"maximum_inclination_angle_horizontal\"],\"description\":"
    "\"Classification method 1\"}},\"required\":[\"settings\",\"classes\"]}"
    ,
    /* example: */
    "{\"settings\":{\"sloping_plane_classes_minimum_angle\":10.0,\"sloping_plane"
    "_classes_maximum_angle\":70.0,\"plane_classification_method\":2},\"classes"
    "\":{\"10\":\"sloping, pointing down and east\",\"1\":\"horizontal, pointing "
    "up\",\"4\":\"sloping, pointing up and north\",\"9\":\"vertical, pointing "
    "west\",\"11\":\"sloping, pointing down and south\",\"8\":\"vertical, pointing "
    "north\",\"12\":\"sloping, pointing down and north\",\"2\":\"sloping, pointing "
    "up and east\",\"3\":\"sloping, pointing up and south\",\"5\":\"sloping, "
    "pointing up and west\",\"7\":\"vertical, pointing south\",\"13\":\"sloping, "
    "pointing down and west\",\"14\":\"horizontal, pointing "
    "down\",\"6\":\"vertical, pointing east\"}}"
};

// Grouping and sorting of point attributes for visualization purposes
const MetaDataItemInfo RDB_RIEGL_POINT_ATTRIBUTE_GROUPS = {
    /* name        */ "riegl.point_attribute_groups",
    /* title       */ "Point Attribute Groups",
    /* description */ "Grouping and sorting of point attributes for visualization purposes",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"title\":\"Point Attribute Groups\",\"$schema\":\"http://js"
    "on-schema.org/draft-04/schema#\",\"patternProperties\":{\"^.*$\":{\"type\":\"a"
    "rray\",\"minItems\":1,\"items\":{\"type\":\"string\",\"description\":\"Point "
    "attribute full name or name pattern (perl regular expression "
    "syntax)\"},\"description\":\"Each field of the object represents a point "
    "attribute group and holds a list of point attributes, where the field "
    "name is the group name.\"}},\"description\":\"Grouping and sorting of "
    "point attributes for visualization "
    "purposes\",\"additionalProperties\":false}"
    ,
    /* example: */
    "{\"Secondary "
    "Attributes\":[\"riegl.mirror_facet\",\"riegl.waveform_available\"],\"Other A"
    "ttributes\":[\"riegl.selected\",\"riegl.visible\"],\"Time\":[\"riegl.timestamp"
    "\"],\"Primary Attributes\":[\"riegl.reflectance\",\"riegl.amplitude\",\"riegl."
    "deviation\"],\"Coordinates/Vectors\":[\"riegl.xyz\",\"riegl.range\",\"riegl.th"
    "eta\",\"riegl.phi\"]}"
};

// Details about point cloud files
const MetaDataItemInfo RDB_RIEGL_POINTCLOUD_INFO = {
    /* name        */ "riegl.pointcloud_info",
    /* title       */ "Point Cloud Information",
    /* description */ "Details about point cloud files",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"properties\":{\"field_of_application\":{\"type\":\"string\""
    ",\"enum\":[\"unknown\",\"SLS\",\"TLS\",\"KLS\",\"MLS\",\"ULS\",\"ALS\",\"BLS\",\"ILS\"],\"d"
    "escription\":\"Field of application\"},\"comments\":{\"type\":\"string\",\"descr"
    "iption\":\"Comments\"},\"project\":{\"type\":\"string\",\"description\":\"Project "
    "name\"}},\"title\":\"Point Cloud Information\",\"$schema\":\"http://json-schem"
    "a.org/draft-04/schema#\",\"description\":\"Details about point cloud "
    "files\"}"
    ,
    /* example: */
    "{\"field_of_application\":\"ALS\",\"comments\":\"Line 3\",\"project\":\"Campaign "
    "4\"}"
};

// Estimated position and orientation information
const MetaDataItemInfo RDB_RIEGL_POSE_ESTIMATION = {
    /* name        */ "riegl.pose_estimation",
    /* title       */ "Pose Estimation",
    /* description */ "Estimated position and orientation information",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"properties\":{\"barometric_height_amsl\":{\"type\":\"numbe"
    "r\",\"description\":\"Altitude determined based on the atmospheric "
    "pressure according to the standard atmosphere laws [m].\"},\"position\":{"
    "\"type\":\"object\",\"properties\":{\"coordinate_2\":{\"type\":\"number\",\"descrip"
    "tion\":\"Coordinate 2 as defined by axis 2 of the specified CRS (e.g., "
    "Y, "
    "Longitude)\"},\"coordinate_3\":{\"type\":\"number\",\"description\":\"Coordinate"
    " 3 as defined by axis 3 of the specified CRS (e.g., Z, Altitude)\"},\"ve"
    "rtical_accuracy\":{\"type\":\"number\",\"minimum\":0,\"description\":\"Vertical "
    "accuracy [m]\",\"exclusiveMinimum\":true},\"horizontal_accuracy\":{\"type\":\""
    "number\",\"minimum\":0,\"description\":\"Horizontal accuracy [m]\",\"exclusive"
    "Minimum\":true},\"coordinate_1\":{\"type\":\"number\",\"description\":\"Coordina"
    "te 1 as defined by axis 1 of the specified CRS (e.g., X, Latitude)\"},\""
    "crs\":{\"type\":\"object\",\"properties\":{\"epsg\":{\"type\":\"integer\",\"minimum\""
    ":0,\"description\":\"EPSG "
    "code\"},\"wkt\":{\"type\":\"string\",\"description\":\"\\\"Well-Known Text\\\" "
    "string, OGC WKT dialect (see http://www.opengeospatial.org/standards/w"
    "kt-crs)\"}},\"required\":[\"epsg\"],\"description\":\"Global Coordinate "
    "Reference System\"}},\"required\":[\"coordinate_1\",\"coordinate_2\",\"coordin"
    "ate_3\",\"horizontal_accuracy\",\"vertical_accuracy\",\"crs\"],\"description\":"
    "\"Position coordinates and position accuracy values as measured by GNSS"
    " in the specified Coordinate Reference System (CRS)\"},\"orientation\":{\""
    "type\":\"object\",\"properties\":{\"yaw_accuracy\":{\"type\":\"number\",\"minimum\""
    ":0,\"description\":\"Yaw angle accuracy [deg]\",\"exclusiveMinimum\":true},\""
    "yaw\":{\"type\":\"number\",\"maximum\":360,\"minimum\":-360,\"description\":\"Yaw "
    "angle about scanner Z-axis [deg]\"},\"pitch_accuracy\":{\"type\":\"number\",\""
    "minimum\":0,\"description\":\"Pitch angle accuracy [deg]\",\"exclusiveMinimu"
    "m\":true},\"roll\":{\"type\":\"number\",\"maximum\":360,\"minimum\":-360,\"descrip"
    "tion\":\"Roll angle about scanner X-axis [deg]\"},\"roll_accuracy\":{\"type\""
    ":\"number\",\"minimum\":0,\"description\":\"Roll angle accuracy [deg]\",\"exclu"
    "siveMinimum\":true},\"pitch\":{\"type\":\"number\",\"maximum\":360,\"minimum\":-3"
    "60,\"description\":\"Pitch angle about scanner Y-axis [deg]\"}},\"required\""
    ":[\"roll\",\"pitch\",\"yaw\",\"roll_accuracy\",\"pitch_accuracy\",\"yaw_accuracy\""
    "],\"description\":\"Orientation values and orientation accuracies, "
    "measured with IMU or inclination sensors.\"}},\"title\":\"Pose Estimation\""
    ",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"description\":\"Es"
    "timated position and orientation information as measured by GNSS, IMU "
    "or inclination sensors\",\"required\":[\"orientation\"]}"
    ,
    /* example: */
    "{\"barometric_height_amsl\":386.7457796227932,\"position\":{\"coordinate_2\""
    ":15.645033406,\"coordinate_3\":362.7124938964844,\"vertical_accuracy\":1.3"
    "314999341964722,\"horizontal_accuracy\":0.810699999332428,\"coordinate_1\""
    ":48.655799473,\"crs\":{\"epsg\":4979,\"wkt\":\"GEOGCS[\\\"WGS84 / Geographic\\\","
    "DATUM[\\\"WGS84\\\",SPHEROID[\\\"WGS84\\\",6378137.000,298.257223563,AUTHORITY"
    "[\\\"EPSG\\\",\\\"7030\\\"]],AUTHORITY[\\\"EPSG\\\",\\\"6326\\\"]],PRIMEM[\\\"Greenwich\\"
    "\",0.0000000000000000,AUTHORITY[\\\"EPSG\\\",\\\"8901\\\"]],UNIT[\\\"Degree\\\",0.0"
    "1745329251994329547,AUTHORITY[\\\"EPSG\\\",\\\"9102\\\"]],AXIS[\\\"Latitude\\\",NO"
    "RTH],AXIS[\\\"Longitude\\\",EAST],AUTHORITY[\\\"EPSG\\\",\\\"4979\\\"]]\"}},\"orient"
    "ation\":{\"yaw_accuracy\":1.0094337839368757,\"yaw\":101.87293630292045,\"pi"
    "tch_accuracy\":0.009433783936875745,\"roll\":3.14743073066123,\"roll_accur"
    "acy\":0.009433783936875745,\"pitch\":1.509153024827064}}"
};

// Details on position and orientation sensors
const MetaDataItemInfo RDB_RIEGL_POSE_SENSORS = {
    /* name        */ "riegl.pose_sensors",
    /* title       */ "Pose Sensors",
    /* description */ "Details on position and orientation sensors",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"properties\":{\"accelerometer\":{\"type\":\"object\",\"prope"
    "rties\":{\"origin\":{\"description\":\"Sensor origin in SOCS [m] at frame "
    "angle = "
    "0\",\"$ref\":\"#/definitions/vector\"},\"offset\":{\"description\":\"Value to be"
    " subtracted from raw measurement values\",\"$ref\":\"#/definitions/vector\""
    "},\"x_axis\":{\"description\":\"Sensitive X axis of sensor at frame angle ="
    " 0\",\"$ref\":\"#/definitions/vector\"},\"z_axis\":{\"description\":\"Sensitive "
    "Z axis of sensor at frame angle = "
    "0\",\"$ref\":\"#/definitions/vector\"},\"y_axis\":{\"description\":\"Sensitive Y"
    " axis of sensor at frame angle = 0\",\"$ref\":\"#/definitions/vector\"},\"un"
    "it\":{\"type\":\"number\",\"minimum\":0,\"description\":\"Unit of raw data and "
    "calibration values, 1 LSB in 9.81 m/s\\u00b2\",\"exclusiveMinimum\":true},"
    "\"relative_nonlinearity\":{\"description\":\"Relative nonlinearity, dimensi"
    "onless\",\"$ref\":\"#/definitions/vector\"}},\"required\":[\"unit\",\"x_axis\",\"y"
    "_axis\",\"z_axis\",\"offset\",\"origin\",\"relative_nonlinearity\"],\"descriptio"
    "n\":\"Accelerometer details\"},\"magnetic_field_sensor\":{\"type\":\"object\",\""
    "properties\":{\"offset\":{\"description\":\"Value to be subtracted from raw "
    "measurement values\",\"$ref\":\"#/definitions/vector\"},\"x_axis\":{\"descript"
    "ion\":\"Sensitive X axis of sensor at frame angle = "
    "0\",\"$ref\":\"#/definitions/vector\"},\"z_axis\":{\"description\":\"Sensitive Z"
    " axis of sensor at frame angle = "
    "0\",\"$ref\":\"#/definitions/vector\"},\"y_axis\":{\"description\":\"Sensitive Y"
    " axis of sensor at frame angle = 0\",\"$ref\":\"#/definitions/vector\"},\"un"
    "it\":{\"type\":\"number\",\"minimum\":0,\"description\":\"Unit of raw data and "
    "calibration values, 1 LSB in "
    "nT\",\"exclusiveMinimum\":true},\"fixed\":{\"description\":\"Distortion of "
    "magnetic field caused by non-rotating scanner part\",\"$ref\":\"#/definiti"
    "ons/vector\"},\"relative_nonlinearity\":{\"description\":\"Relative "
    "nonlinearity, dimensionless\",\"$ref\":\"#/definitions/vector\"}},\"required"
    "\":[\"unit\",\"x_axis\",\"y_axis\",\"z_axis\",\"offset\",\"fixed\",\"relative_nonlin"
    "earity\"],\"description\":\"Magnetic Field Sensor details\"},\"gyroscope\":{\""
    "type\":\"object\",\"properties\":{\"origin\":{\"description\":\"Sensor origin in"
    " SOCS [m] at frame angle = "
    "0\",\"$ref\":\"#/definitions/vector\"},\"offset\":{\"description\":\"Value to be"
    " subtracted from raw measurement values\",\"$ref\":\"#/definitions/vector\""
    "},\"x_axis\":{\"description\":\"Sensitive X axis of sensor at frame angle ="
    " 0\",\"$ref\":\"#/definitions/vector\"},\"z_axis\":{\"description\":\"Sensitive "
    "Z axis of sensor at frame angle = "
    "0\",\"$ref\":\"#/definitions/vector\"},\"y_axis\":{\"description\":\"Sensitive Y"
    " axis of sensor at frame angle = 0\",\"$ref\":\"#/definitions/vector\"},\"un"
    "it\":{\"type\":\"number\",\"minimum\":0,\"description\":\"Unit of raw data and "
    "calibration values, 1 LSB in rad/s\",\"exclusiveMinimum\":true},\"relative"
    "_nonlinearity\":{\"description\":\"Relative nonlinearity, dimensionless\",\""
    "$ref\":\"#/definitions/vector\"}},\"required\":[\"unit\",\"x_axis\",\"y_axis\",\"z"
    "_axis\",\"offset\",\"origin\",\"relative_nonlinearity\"],\"description\":\"Gyros"
    "cope details\"}},\"title\":\"Pose Sensors\",\"$schema\":\"http://json-schema.o"
    "rg/draft-04/schema#\",\"description\":\"Details on position and "
    "orientation sensors\",\"definitions\":{\"vector\":{\"type\":\"array\",\"minItems"
    "\":3,\"maxItems\":3,\"items\":{\"type\":\"number\",\"description\":\"Index 0=X, "
    "1=Y, 2=Z component\"}}},\"required\":[\"gyroscope\",\"accelerometer\",\"magnet"
    "ic_field_sensor\"]}"
    ,
    /* example: */
    "{\"accelerometer\":{\"origin\":[0.026900000870227814,-0.03999999910593033,"
    "-0.08950000256299973],\"offset\":[-733.3636474609375,58.969032287597656,"
    "1060.2550048828125],\"x_axis\":[-15008.123046875,56.956390380859375,-60."
    "5175666809082],\"z_axis\":[1.639882206916809,15166.744140625,-116.997428"
    "89404297],\"y_axis\":[-7.027288913726807,-44.12333679199219,14952.370117"
    "1875],\"unit\":6.666666740784422e-05,\"relative_nonlinearity\":[0.0,0.0,0."
    "0]},\"magnetic_field_sensor\":{\"offset\":[-23812.052734375,5606.576660156"
    "25,2493.28125],\"x_axis\":[-0.011162743903696537,-2.315962774446234e-05,"
    "0.00016818844596855342],\"z_axis\":[0.00041987866279669106,7.87697790656"
    "2388e-05,0.011407104320824146],\"y_axis\":[0.00027888521435670555,-0.011"
    "427424848079681,-5.204829722060822e-05],\"unit\":91.74311828613281,\"fixe"
    "d\":[-1576.010498046875,1596.081787109375,0.0],\"relative_nonlinearity\":"
    "[0.0,0.0,0.0]},\"gyroscope\":{\"origin\":[0.026900000870227814,-0.03999999"
    "910593033,-0.08950000256299973],\"offset\":[-50.92609786987305,146.15643"
    "310546875,62.4327278137207],\"x_axis\":[-121.195556640625,0.821971416473"
    "3887,0.2313031703233719],\"z_axis\":[0.555869996547699,119.2213516235351"
    "6,0.467585027217865],\"y_axis\":[-0.440765917301178,-0.7897399663925171,"
    "119.5894775390625],\"unit\":0.00014544410805683583,\"relative_nonlinearit"
    "y\":[2.888176311444113e-07,1.06274164579645e-07,-1.7186295080634935e-39"
    "]}}"
};

// Laser pulse position modulation used for MTA resolution
const MetaDataItemInfo RDB_RIEGL_PULSE_POSITION_MODULATION = {
    /* name        */ "riegl.pulse_position_modulation",
    /* title       */ "Pulse Position Modulation",
    /* description */ "Laser pulse position modulation used for MTA resolution",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"properties\":{\"num_mod_ampl\":{\"type\":\"integer\",\"maxim"
    "um\":255,\"minimum\":0,\"description\":\"Number of different modulation "
    "amplitudes (2: binary modulation)\"},\"pulse_interval\":{\"type\":\"array\",\""
    "items\":{\"type\":\"number\",\"minimum\":0},\"description\":\"Explicit table of "
    "the pulse position modulation used for MTA resolution. Table gives "
    "times between successive laser pulses in seconds.\"},\"length\":{\"type\":\""
    "integer\",\"maximum\":255,\"minimum\":0,\"description\":\"Length of code\"},\"co"
    "de_phase_mode\":{\"type\":\"integer\",\"maximum\":255,\"minimum\":0,\"descriptio"
    "n\":\"0: no synchronization, 1: toggle between 2 phases, 2: increment "
    "with phase_increment\"},\"phase_step\":{\"type\":\"integer\",\"maximum\":255,\"m"
    "inimum\":0,\"description\":\"Step width in phase of modulation code from "
    "line to line\"}},\"title\":\"Pulse Position Modulation\",\"$schema\":\"http://"
    "json-schema.org/draft-04/schema#\",\"description\":\"Laser pulse position "
    "modulation used for MTA "
    "resolution\",\"required\":[\"length\",\"num_mod_ampl\",\"pulse_interval\"]}"
    ,
    /* example: */
    "{\"num_mod_ampl\":2,\"pulse_interval\":[2.759375e-06,2.759375e-06,2.759375"
    "e-06,2.759375e-06,2.821875e-06,2.759375e-06,2.759375e-06,2.821875e-06,"
    "2.759375e-06,2.821875e-06,2.821875e-06,2.759375e-06,2.759375e-06,2.821"
    "875e-06,2.821875e-06,2.821875e-06,2.821875e-06,2.821875e-06,2.759375e-"
    "06,2.759375e-06,2.759375e-06,2.821875e-06,2.821875e-06,2.759375e-06,2."
    "821875e-06,2.821875e-06,2.821875e-06,2.759375e-06,2.821875e-06,2.75937"
    "5e-06,2.821875e-06],\"length\":31,\"code_phase_mode\":2,\"phase_step\":5}"
};

// Statistics about target distance wrt. SOCS origin
const MetaDataItemInfo RDB_RIEGL_RANGE_STATISTICS = {
    /* name        */ "riegl.range_statistics",
    /* title       */ "Range Statistics",
    /* description */ "Statistics about target distance wrt. SOCS origin",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"properties\":{\"std_dev\":{\"type\":\"number\",\"description"
    "\":\"Standard "
    "deviation\"},\"maximum\":{\"type\":\"number\",\"description\":\"Maximum "
    "value\"},\"minimum\":{\"type\":\"number\",\"description\":\"Minimum "
    "value\"},\"average\":{\"type\":\"number\",\"description\":\"Average "
    "value\"}},\"title\":\"Range Statistics\",\"$schema\":\"http://json-schema.org/"
    "draft-04/schema#\",\"description\":\"Statistics about target distance wrt."
    " SOCS origin\",\"required\":[\"minimum\",\"average\",\"maximum\",\"std_dev\"]}"
    ,
    /* example: */
    "{\"std_dev\":24.349,\"maximum\":574.35,\"minimum\":0.919,\"average\":15.49738}"
};

// Receiver Internals
const MetaDataItemInfo RDB_RIEGL_RECEIVER_INTERNALS = {
    /* name        */ "riegl.receiver_internals",
    /* title       */ "Receiver Internals",
    /* description */ "Receiver Internals",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"properties\":{\"sr\":{\"type\":\"number\",\"minimum\":0,\"desc"
    "ription\":\"Sample rate [Hz]\",\"exclusiveMinimum\":true},\"ns\":{\"type\":\"int"
    "eger\",\"maximum\":4095,\"minimum\":0,\"description\":\"Number of samples\"},\"n"
    "t\":{\"type\":\"integer\",\"maximum\":255,\"minimum\":0,\"description\":\"Number "
    "of traces\"},\"t\":{\"type\":\"object\",\"additionalProperties\":false,\"pattern"
    "Properties\":{\"^[0-9]+$\":{\"description\":\"one field per channel, field "
    "name is channel index\",\"$ref\":\"#/definitions/fp\"}}},\"a\":{\"type\":\"array"
    "\",\"minItems\":1,\"maxItems\":256,\"items\":{\"type\":\"number\"},\"description\":"
    "\"Amplitude [dB]\"},\"si\":{\"type\":\"number\",\"maximum\":255,\"minimum\":0,\"des"
    "cription\":\"Start index "
    "(hw_start)\"},\"ex\":{\"type\":\"object\",\"description\":\"DEPRECATED, use "
    "'riegl.exponential_decomposition' instead\"},\"mw\":{\"type\":\"number\",\"max"
    "imum\":4095,\"minimum\":0,\"description\":\"Maximum weight\",\"exclusiveMinimu"
    "m\":true},\"tbl\":{\"type\":\"array\",\"minItems\":1,\"items\":{\"$ref\":\"#/definit"
    "ions/fp_table\"},\"description\":\"various internal "
    "data\"}},\"title\":\"Receiver Internals\",\"$schema\":\"http://json-schema.org"
    "/draft-04/schema#\",\"description\":\"Receiver Internals\",\"definitions\":{\""
    "fp_table\":{\"type\":\"object\",\"desription\":\"scanner internal data\",\"prope"
    "rties\":{\"tv\":{\"type\":\"array\",\"minItems\":1,\"maxItems\":2048,\"items\":{\"on"
    "eOf\":[{\"$ref\":\"#/definitions/fp_table_row\"},{\"type\":\"number\"}]}},\"ny\":"
    "{\"type\":\"integer\",\"min\":1,\"max\":2048,\"description\":\"number of y entrie"
    "s\"},\"tc\":{\"type\":\"integer\",\"min\":0,\"max\":255,\"description\":\"table data"
    " type "
    "code\"},\"ch\":{\"type\":\"integer\",\"min\":0,\"max\":255,\"description\":\"channel"
    " number\"},\"nx\":{\"type\":\"integer\",\"min\":1,\"max\":2048,\"description\":\"num"
    "ber of x entries\"}},\"required\":[\"ch\",\"tc\",\"nx\",\"ny\",\"tv\"]},\"fp\":{\"type"
    "\":\"object\",\"properties\":{\"w\":{\"type\":\"array\",\"minItems\":1,\"maxItems\":2"
    "56,\"items\":{\"type\":\"array\",\"minItems\":5,\"maxItems\":5,\"items\":{\"type\":\""
    "number\"}}},\"s\":{\"type\":\"array\",\"minItems\":1,\"maxItems\":256,\"items\":{\"t"
    "ype\":\"array\",\"minItems\":1,\"maxItems\":4096,\"items\":{\"type\":\"number\"}}}}"
    ",\"required\":[\"s\",\"w\"],\"description\":\"Fingerprint values\"},\"fp_table_ro"
    "w\":{\"type\":\"array\",\"minItems\":1,\"maxItems\":2048,\"items\":{\"type\":\"numbe"
    "r\"}}}}"
    ,
    /* example: */
    "{\"sr\":7959997000.0,\"ns\":400,\"nt\":128,\"t\":{\"0\":{\"w\":[[78,86,126,134,31]"
    ",[78,86,126,134,31]],\"s\":[[1.23,4.56],[7.89,0.12]]},\"1\":{\"w\":[[78,86,1"
    "26,134,31],[78,86,126,134,31]],\"s\":[[1.23,4.56],[7.89,0.12]]}},\"a\":[-1"
    ".55],\"si\":48,\"mw\":31,\"tbl\":[{\"tv\":[[1,2,3,4,5],[1.1,2.2,3.3,4.4,5.5]],"
    "\"ny\":2,\"tc\":1,\"ch\":0,\"nx\":5}]}"
};

// Lookup table for reflectance calculation based on amplitude and range
const MetaDataItemInfo RDB_RIEGL_REFLECTANCE_CALCULATION = {
    /* name        */ "riegl.reflectance_calculation",
    /* title       */ "Reflectance Calculation Table",
    /* description */ "Lookup table for reflectance calculation based on amplitude and range",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"properties\":{\"content\":{\"type\":\"array\",\"minItems\":1,"
    "\"maxItems\":2000,\"items\":{\"type\":\"number\"},\"description\":\"Correction "
    "value [dB] to be added to the "
    "amplitude\"},\"delta\":{\"type\":\"number\",\"description\":\"Delta between "
    "table entries [m], first entry is at range = 0 "
    "m\"}},\"title\":\"Reflectance Calculation Table\",\"$schema\":\"http://json-sc"
    "hema.org/draft-04/schema#\",\"description\":\"Lookup table for reflectance"
    " calculation based on amplitude and "
    "range\",\"required\":[\"delta\",\"content\"]}"
    ,
    /* example: */
    "{\"content\":[-33.01],\"delta\":0.150918}"
};

// Range-dependent and scan-angle-dependent correction of reflectance reading
const MetaDataItemInfo RDB_RIEGL_REFLECTANCE_CORRECTION = {
    /* name        */ "riegl.reflectance_correction",
    /* title       */ "Near-Range Reflectance Correction",
    /* description */ "Range-dependent and scan-angle-dependent correction of reflectance reading",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"properties\":{\"reflectance_correction_db\":{\"type\":\"ar"
    "ray\",\"items\":{\"type\":\"array\",\"items\":{\"type\":\"number\",\"description\":\"c"
    "olumns (each value corresponds to an angle)\"},\"description\":\"rows "
    "(each array corresponds to a range)\"},\"description\":\"Near range "
    "reflectance correction in dB as a function of range over angle\"},\"rang"
    "es_m\":{\"type\":\"array\",\"items\":{\"type\":\"number\"},\"description\":\"Range ["
    "m]\"},\"line_angles_deg\":{\"type\":\"array\",\"items\":{\"type\":\"number\"},\"desc"
    "ription\":\"Angle [deg]\"}},\"title\":\"Near-range reflectance correction\",\""
    "$schema\":\"http://json-schema.org/draft-04/schema#\",\"description\":\"Rang"
    "e-dependent and scan-angle-dependent correction of reflectance reading"
    "\",\"required\":[\"ranges_m\",\"line_angles_deg\",\"reflectance_correction_db\""
    "]}"
    ,
    /* example: */
    "{\"reflectance_correction_db\":[[0.8,0.7,0.6,0.5,0.4,0.3,0.2,0.1,0.05,0."
    "01],[0.8,0.7,0.6,0.5,0.4,0.3,0.2,0.1,0.05,0.01],[0.8,0.7,0.6,0.5,0.4,0"
    ".3,0.2,0.1,0.05,0.01],[0.8,0.7,0.6,0.5,0.4,0.3,0.2,0.1,0.05,0.01]],\"ra"
    "nges_m\":[0.0,1.0,2.0,3.0],\"line_angles_deg\":[0.0,0.5,1.0,1.5,1.0,2.0,2"
    ".5,3.0,3.5,4.0]}"
};

// Scan pattern description
const MetaDataItemInfo RDB_RIEGL_SCAN_PATTERN = {
    /* name        */ "riegl.scan_pattern",
    /* title       */ "Scan Pattern",
    /* description */ "Scan pattern description",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"definitions\":{\"program\":{\"type\":\"object\",\"properties\":{\"name\":{\"type"
    "\":\"string\",\"description\":\"Name of measurement program\"},\"laser_prr\":{\""
    "type\":\"number\",\"minimum\":0,\"description\":\"Laser Pulse Repetition Rate "
    "[Hz]\",\"exclusiveMinimum\":false}},\"required\":[\"name\"],\"description\":\"Me"
    "asurement program\"}},\"properties\":{\"segments\":{\"type\":\"object\",\"proper"
    "ties\":{\"list\":{\"type\":\"array\",\"items\":{\"type\":\"object\",\"properties\":{\""
    "increment\":{\"type\":\"number\",\"maximum\":90.0,\"minimum\":0.0,\"description\""
    ":\"Increment of angle in SOCS [deg]\"},\"start\":{\"type\":\"number\",\"maximum"
    "\":360.0,\"minimum\":0.0,\"description\":\"Start angle in SOCS [deg]\"},\"stop"
    "\":{\"type\":\"number\",\"maximum\":720.0,\"minimum\":0.0,\"description\":\"Stop "
    "angle in SOCS "
    "[deg]\"}},\"required\":[\"start\",\"stop\",\"increment\"],\"description\":\"Line "
    "Scan Segment\"}},\"program\":{\"$ref\":\"#/definitions/program\"}},\"required\""
    ":[\"list\"],\"description\":\"Segmented Line Scan Pattern\"},\"line\":{\"type\":"
    "\"object\",\"properties\":{\"program\":{\"$ref\":\"#/definitions/program\"},\"inc"
    "rement\":{\"type\":\"number\",\"maximum\":90.0,\"minimum\":0.0,\"description\":\"I"
    "ncrement of angle in SOCS [deg]\"},\"start\":{\"type\":\"number\",\"maximum\":3"
    "60.0,\"minimum\":0.0,\"description\":\"Start angle in SOCS [deg]\"},\"stop\":{"
    "\"type\":\"number\",\"maximum\":720.0,\"minimum\":0.0,\"description\":\"Stop "
    "angle in SOCS "
    "[deg]\"}},\"required\":[\"start\",\"stop\",\"increment\"],\"description\":\"Line "
    "Scan Pattern\"},\"rectangular\":{\"type\":\"object\",\"properties\":{\"phi_incre"
    "ment\":{\"type\":\"number\",\"maximum\":90.0,\"minimum\":0.0,\"description\":\"Inc"
    "rement of phi angle in SOCS [deg]\"},\"theta_start\":{\"type\":\"number\",\"ma"
    "ximum\":180.0,\"minimum\":0.0,\"description\":\"Start theta angle in SOCS [d"
    "eg]\"},\"phi_stop\":{\"type\":\"number\",\"maximum\":720.0,\"minimum\":0.0,\"descr"
    "iption\":\"Stop phi angle in SOCS [deg]\"},\"program\":{\"$ref\":\"#/definitio"
    "ns/program\"},\"phi_start\":{\"type\":\"number\",\"maximum\":360.0,\"minimum\":0."
    "0,\"description\":\"Start phi angle in SOCS [deg]\"},\"theta_stop\":{\"type\":"
    "\"number\",\"maximum\":180.0,\"minimum\":0.0,\"description\":\"Stop theta angle"
    " in SOCS [deg]\"},\"theta_increment\":{\"type\":\"number\",\"maximum\":90.0,\"mi"
    "nimum\":0.0,\"description\":\"Increment of theta angle in SOCS [deg]\"}},\"r"
    "equired\":[\"phi_start\",\"phi_stop\",\"phi_increment\",\"theta_start\",\"theta_"
    "stop\",\"theta_increment\"],\"description\":\"Rectangular Field Of View Scan"
    " Pattern\"}},\"title\":\"Scan Pattern\",\"$schema\":\"http://json-schema.org/d"
    "raft-04/schema#\",\"description\":\"Scan pattern description\"}"
    ,
    /* example: */
    "{\"rectangular\":{\"phi_increment\":0.04,\"theta_start\":30.0,\"phi_stop\":270"
    ".0,\"program\":{\"name\":\"High Speed\",\"laser_prr\":100000.0},\"phi_start\":45"
    ".0,\"theta_stop\":130.0,\"theta_increment\":0.04}}"
};

// Details about laser shot files
const MetaDataItemInfo RDB_RIEGL_SHOT_INFO = {
    /* name        */ "riegl.shot_info",
    /* title       */ "Shot Information",
    /* description */ "Details about laser shot files",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"properties\":{\"shot_file\":{\"type\":\"object\",\"propertie"
    "s\":{\"file_uuid\":{\"type\":\"string\",\"description\":\"File's Universally "
    "Unique Identifier (RFC "
    "4122)\"},\"file_extension\":{\"type\":\"string\",\"description\":\"Shot file "
    "extension, without the leading "
    "dot\"}},\"required\":[\"file_extension\"]}},\"title\":\"Shot Information\",\"$sc"
    "hema\":\"http://json-schema.org/draft-04/schema#\",\"description\":\"Details"
    " about laser shot files\"}"
    ,
    /* example: */
    "{\"shot_file\":{\"file_uuid\":\"26a00815-67c0-4bff-8fe8-c577378fe663\",\"file"
    "_extension\":\"sodx\"}}"
};

// Point filters applied in addition to the application-defined filters
const MetaDataItemInfo RDB_RIEGL_STORED_FILTERS = {
    /* name        */ "riegl.stored_filters",
    /* title       */ "Stored Filters",
    /* description */ "Point filters applied in addition to the application-defined filters",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"properties\":{\"activated\":{\"type\":\"boolean\",\"descript"
    "ion\":\"Apply ('true') or ignore ('false') all filters\"},\"filters\":{\"typ"
    "e\":\"array\",\"items\":{\"type\":\"object\",\"properties\":{\"title\":{\"type\":\"str"
    "ing\",\"description\":\"A short filter title (e.g. for display in a "
    "selection list)\"},\"filter\":{\"type\":\"string\",\"description\":\"The RDB "
    "filter string to apply (e.g. when reading points or index), details "
    "see documentation of function "
    "select()\"},\"activated\":{\"type\":\"boolean\",\"description\":\"Apply ('true')"
    " or ignore ('false') this "
    "filter\"},\"description\":{\"type\":\"string\",\"description\":\"A brief "
    "description of the filter (e.g. for display in a tooltip)\"}},\"required"
    "\":[\"activated\",\"title\",\"description\",\"filter\"],\"description\":\"Point "
    "filter definition\"},\"description\":\"List of point "
    "filters\"}},\"title\":\"Stored filters\",\"$schema\":\"http://json-schema.org/"
    "draft-04/schema#\",\"description\":\"Point filters applied in addition to "
    "the application-defined filters\",\"required\":[\"activated\",\"filters\"]}"
    ,
    /* example: */
    "{\"activated\":true,\"filters\":[{\"title\":\"Ignore uncertain points from "
    "MTA resolution\",\"filter\":\"riegl.mta_uncertain_point == "
    "0\",\"activated\":false,\"description\":\"Ignore points with uncertain MTA "
    "zone assignment\"},{\"title\":\"Ignore points below dynamic trigger "
    "level\",\"filter\":\"riegl.dyntrig_uncertain_point == "
    "0\",\"activated\":false,\"description\":\"Ignore points with an echo signal "
    "amplitude below the dynamic trigger\"},{\"title\":\"Ignore points outside "
    "outer AABB\",\"filter\":\"riegl.point_outside_aabb_bocs == "
    "0\",\"activated\":false,\"description\":\"Ignore points that are outside the"
    " outer AABB in BOCS\"},{\"title\":\"Ignore points inside inner "
    "AABB\",\"filter\":\"riegl.point_inside_aabb_bocs == "
    "0\",\"activated\":false,\"description\":\"Ignore points that are inside the "
    "inner AABB in BOCS\"}]}"
};

// Details of major system components like lidar sensors, cameras and navigation devices
const MetaDataItemInfo RDB_RIEGL_SYSTEM_DESCRIPTION = {
    /* name        */ "riegl.system_description",
    /* title       */ "System Description",
    /* description */ "Details of major system components like lidar sensors, cameras and navigation devices",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"properties\":{\"author\":{\"type\":\"string\",\"description\""
    ":\"Name of the author that created the "
    "document\"},\"timestamp\":{\"type\":\"string\",\"description\":\"Date and time "
    "of creation (e.g. 2019-06-19T13:32:10+02:00)\"},\"system\":{\"type\":\"objec"
    "t\",\"description\":\"The actual system description, details see "
    "documentation of RIEGL System "
    "Description\"},\"version\":{\"type\":\"string\",\"description\":\"Document "
    "format version\"},\"$class\":{\"type\":\"string\",\"enum\":[\"Document\"],\"descri"
    "ption\":\"Object class name\"}},\"title\":\"System Description\",\"$schema\":\"h"
    "ttp://json-schema.org/draft-04/schema#\",\"description\":\"Details of "
    "major system components like lidar sensors, cameras and navigation dev"
    "ices\",\"required\":[\"$class\",\"version\",\"author\",\"timestamp\",\"system\"]}"
    ,
    /* example: */
    "{\"author\":\"RIEGL LMS GmbH, Austria\",\"timestamp\":\"2022-09-30T11:56:26+0"
    "0:00\",\"system\":{\"details\":\"see documentation of RIEGL System "
    "Description\"},\"version\":\"1.2.1\",\"$class\":\"Document\"}"
};

// Conversion of background radiation raw values to temperatures in °C
const MetaDataItemInfo RDB_RIEGL_TEMPERATURE_CALCULATION = {
    /* name        */ "riegl.temperature_calculation",
    /* title       */ "Temperature Calculation Table",
    /* description */ "Conversion of background radiation raw values to temperatures in °C",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"properties\":{\"Si\":{\"description\":\"Conversion table "
    "for Si channel\",\"$ref\":\"#/definitions/conversion_table\"},\"InGaAs_Si_Di"
    "fference\":{\"description\":\"Conversion table for InGaAs - Si difference\""
    ",\"$ref\":\"#/definitions/conversion_table\"},\"InGaAs\":{\"description\":\"Con"
    "version table for InGaAs channel\",\"$ref\":\"#/definitions/conversion_tab"
    "le\"}},\"title\":\"Temperature Calculation Table\",\"$schema\":\"http://json-s"
    "chema.org/draft-04/schema#\",\"description\":\"Conversion of background "
    "radiation raw values to temperatures in \\u00b0C\",\"definitions\":{\"conve"
    "rsion_table\":{\"type\":\"object\",\"properties\":{\"temperature\":{\"type\":\"arr"
    "ay\",\"items\":{\"type\":\"number\"},\"description\":\"Temperature [\\u00b0C]\"},\""
    "value\":{\"type\":\"array\",\"items\":{\"type\":\"number\"},\"description\":\"LSB "
    "[1]\"}},\"required\":[\"value\",\"temperature\"]}}}"
    ,
    /* example: */
    "{\"Si\":{\"temperature\":[546.300048828125,548.8164051212026,551.314393850"
    "0972,554.0144257850053,556.604252334815,559.2124464488079,561.80227299"
    "86177,564.4104671126105,567.0002936624203],\"value\":[0.0,64.00097659230"
    "323,128.0019531846065,192.0029297769097,256.0039063692129,320.00488296"
    "151616,384.0058595538194,448.0068361461226,512.0078127384259]},\"InGaAs"
    "_Si_Difference\":{\"temperature\":[1749.977111117893,1749.977111117893,17"
    "49.977111117893,1749.977111117893,1749.977111117893,1749.977111117893,"
    "1744.7813348796044,1681.9971312601092,1622.3944822534868],\"value\":[100"
    "0.0,1100.090029602954,1200.04425183874,1300.1342814416948,1400.0885036"
    "774805,1500.0427259132668,1600.1327555162209,1700.0869777520065,1800.0"
    "411999877924]},\"InGaAs\":{\"temperature\":[307.22196722535614,309.1153478"
    "247277,311.1188086915047,313.10025350480055,315.2137946389828,317.2172"
    "555057597,319.2207163725366,321.2021611858325,323.3157023200148],\"valu"
    "e\":[0.0,64.00097659230323,128.0019531846065,192.0029297769097,256.0039"
    "063692129,320.00488296151616,384.0058595538194,448.0068361461226,512.0"
    "078127384259]}}"
};

// Base of timestamps (epoch)
const MetaDataItemInfo RDB_RIEGL_TIME_BASE = {
    /* name        */ "riegl.time_base",
    /* title       */ "Time Base",
    /* description */ "Base of timestamps (epoch)",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"properties\":{\"epoch\":{\"type\":\"string\",\"description\":"
    "\"Date and time of timestamp '0' as proposed by RFC 3339 (e.g. 2015-10-"
    "27T00:00:00+01:00).\"},\"system\":{\"type\":\"string\",\"enum\":[\"unknown\",\"UTC"
    "\",\"GPS\"],\"description\":\"Time system (time standard)\"},\"source\":{\"type\""
    ":\"string\",\"enum\":[\"unknown\",\"RTC\",\"GNSS\"],\"description\":\"Timestamp "
    "source\"}},\"title\":\"Time Base\",\"$schema\":\"http://json-schema.org/draft-"
    "04/schema#\",\"description\":\"Base of timestamps "
    "(epoch)\",\"required\":[\"epoch\",\"source\"]}"
    ,
    /* example: */
    "{\"epoch\":\"2015-10-27T00:00:00+00:00\",\"system\":\"UTC\",\"source\":\"GNSS\"}"
};

// Details about position+orientation files
const MetaDataItemInfo RDB_RIEGL_TRAJECTORY_INFO = {
    /* name        */ "riegl.trajectory_info",
    /* title       */ "Trajectory Information",
    /* description */ "Details about position+orientation files",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"properties\":{\"settings\":{\"type\":\"string\",\"descriptio"
    "n\":\"Settings used to calculate the trajectory (descriptive text)\"},\"ti"
    "me_interval\":{\"type\":\"object\",\"properties\":{\"std_dev\":{\"type\":\"number\""
    ",\"description\":\"Standard deviation of intervals "
    "[s]\"},\"maximum\":{\"type\":\"number\",\"description\":\"Maximum time interval "
    "[s]\"},\"minimum\":{\"type\":\"number\",\"description\":\"Minimum time interval "
    "[s]\"},\"average\":{\"type\":\"number\",\"description\":\"Average time interval "
    "[s]\"}},\"required\":[\"minimum\",\"average\",\"maximum\",\"std_dev\"],\"descripti"
    "on\":\"Time interval statistics\"},\"field_of_application\":{\"type\":\"string"
    "\",\"enum\":[\"unknown\",\"SLS\",\"TLS\",\"KLS\",\"MLS\",\"ULS\",\"ALS\",\"BLS\",\"ILS\"],\""
    "description\":\"Field of "
    "application\"},\"device\":{\"type\":\"string\",\"description\":\"Navigation "
    "device, e.g. name/type/serial\"},\"navigation_frame\":{\"type\":\"string\",\"e"
    "num\":[\"unknown\",\"NED\",\"ENU\"],\"description\":\"Navigation frame (NED: "
    "North-East-Down, ENU: "
    "East-North-Up)\"},\"software\":{\"type\":\"string\",\"description\":\"Software "
    "that calculated the trajectory (this may be the same or different "
    "software than the one that created the "
    "file)\"},\"location\":{\"type\":\"string\",\"description\":\"Project location, "
    "e.g. "
    "city/state/country\"},\"company\":{\"type\":\"string\",\"description\":\"Company"
    " name\"},\"project\":{\"type\":\"string\",\"description\":\"Project "
    "name\"}},\"title\":\"Trajectory Information\",\"$schema\":\"http://json-schema"
    ".org/draft-04/schema#\",\"description\":\"Details about "
    "position+orientation "
    "files\",\"required\":[\"time_interval\",\"navigation_frame\"]}"
    ,
    /* example: */
    "{\"settings\":\"default\",\"time_interval\":{\"std_dev\":5.51e-07,\"maximum\":0."
    "005004883,\"minimum\":0.00500032,\"average\":0.00500053},\"field_of_applica"
    "tion\":\"MLS\",\"device\":\"IMU Model 12/1, Serial# "
    "12345\",\"navigation_frame\":\"NED\",\"software\":\"Navigation Software "
    "XYZ\",\"location\":\"Horn\",\"company\":\"RIEGL LMS\",\"project\":\"Campaign 3\"}"
};

// Trigger-Timestamping-Unit/IP configuration
const MetaDataItemInfo RDB_RIEGL_TTIP_CONFIGURATION = {
    /* name        */ "riegl.ttip_configuration",
    /* title       */ "TTIP Configuration",
    /* description */ "Trigger-Timestamping-Unit/IP configuration",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"properties\":{\"in_max_duration\":{\"type\":\"integer\",\"mi"
    "nimum\":0,\"description\":\"stops measurement of pulse duration of input "
    "signal [0.1 "
    "msec]\"},\"dmi_dist_per_tick\":{\"type\":\"number\",\"description\":\"dmi, "
    "distance per tick, just informative [m]\"},\"ext_delay\":{\"type\":\"integer"
    "\",\"minimum\":0,\"description\":\"external trigger, time delay [0.1 "
    "msec]\"},\"ext_signal\":{\"type\":\"integer\",\"minimum\":0,\"description\":\"0 .."
    " use input signal, 1 .. use output signal of channel\"},\"ttip_version\":"
    "{\"type\":\"integer\",\"minimum\":0,\"description\":\"following main.sub.ss.sss"
    "\"},\"out_interval\":{\"type\":\"integer\",\"minimum\":0,\"description\":\"output "
    "pulse interval [0.1 msec]\"},\"dmi_min_time\":{\"type\":\"integer\",\"minimum\""
    ":0,\"description\":\"dmi, minimum time interval between trigger events "
    "[0.1 "
    "msec]\"},\"output_usage\":{\"type\":\"integer\",\"minimum\":0,\"description\":\"0 "
    ".. no output, 1 .. output derived from internal clock, 2 .. output "
    "derived from dmi, 3 .. output derived from external signal, 4 .. "
    "output static low, 5 .. output static high\"},\"dmi_max_time\":{\"type\":\"i"
    "nteger\",\"minimum\":0,\"description\":\"dmi, maximum time interval between "
    "trigger events [0.1 "
    "msec]\"},\"in_polarity\":{\"type\":\"integer\",\"minimum\":0,\"description\":\"0 "
    ".. positive edge, 1 .. negative edge\"},\"out_num_pulses\":{\"type\":\"integ"
    "er\",\"minimum\":0,\"description\":\"number of output pulses to be "
    "generated, 0 .. infinite\"},\"ext_subdivider\":{\"type\":\"integer\",\"minimum"
    "\":0,\"description\":\"reduces the frequency, default 1\"},\"in_min_duration"
    "\":{\"type\":\"integer\",\"minimum\":0,\"description\":\"input signals with "
    "smaller pulse durations are ignored [0.1 msec]\"},\"ext_bitmask\":{\"type\""
    ":\"integer\",\"minimum\":0,\"description\":\"defines which of the internal "
    "pulse generators are to be started\"},\"num_channel\":{\"type\":\"integer\",\""
    "minimum\":0,\"description\":\"number of input/output channels\"},\"in_max_de"
    "lay\":{\"type\":\"integer\",\"minimum\":0,\"description\":\"maximum delay to "
    "output pulse before fake event is generated [0.1 msec], zero indicates"
    " that no fake events are "
    "generated\"},\"output_descr\":{\"type\":\"string\",\"description\":\"descriptive"
    " string\"},\"input_usage\":{\"type\":\"integer\",\"minimum\":0,\"description\":\"0"
    " .. deactivated, 1 .. just detecting and timestamping\"},\"out_duration\""
    ":{\"type\":\"integer\",\"minimum\":0,\"description\":\"output pulse duration "
    "[0.1 msec]\"},\"out_delay\":{\"type\":\"integer\",\"minimum\":0,\"description\":\""
    "output pulse initial delay after start [0.1 "
    "msec]\"},\"ext_channel\":{\"type\":\"integer\",\"minimum\":0,\"description\":\"ID "
    "of channel used as external trigger input, 32 indicates "
    "none\"},\"out_polarity\":{\"type\":\"integer\",\"minimum\":0,\"description\":\"0 "
    ".. positive edge, 1 .. negative "
    "edge\"},\"channel\":{\"type\":\"integer\",\"minimum\":0,\"description\":\"ID of "
    "input/output "
    "channel\"},\"input_descr\":{\"type\":\"string\",\"description\":\"descriptive "
    "string\"},\"dmi_incr\":{\"type\":\"integer\",\"description\":\"dmi, increment in"
    " ticks\"}},\"title\":\"TTIP Configuration\",\"$schema\":\"http://json-schema.o"
    "rg/draft-04/schema#\",\"description\":\"Trigger-Timestamping-Unit/IP confi"
    "guration\",\"required\":[\"ttip_version\",\"num_channel\",\"ext_channel\",\"ext_"
    "signal\",\"ext_delay\",\"ext_subdivider\",\"ext_bitmask\",\"dmi_incr\",\"dmi_min"
    "_time\",\"dmi_max_time\",\"dmi_dist_per_tick\",\"channel\",\"output_descr\",\"in"
    "put_descr\",\"output_usage\",\"input_usage\",\"out_polarity\",\"out_duration\","
    "\"out_interval\",\"out_delay\",\"out_num_pulses\",\"in_polarity\",\"in_min_dura"
    "tion\",\"in_max_duration\",\"in_max_delay\"]}"
    ,
    /* example: */
    "{\"in_max_duration\":10000,\"dmi_dist_per_tick\":0.0,\"ext_delay\":0,\"ext_si"
    "gnal\":0,\"ttip_version\":1,\"out_interval\":10000,\"dmi_min_time\":0,\"output"
    "_usage\":1,\"dmi_max_time\":0,\"in_polarity\":0,\"out_num_pulses\":1,\"ext_sub"
    "divider\":1,\"in_min_duration\":0,\"ext_bitmask\":0,\"num_channel\":9,\"in_max"
    "_delay\":9990,\"output_descr\":\"Port 1 - Trigger\",\"input_usage\":1,\"out_du"
    "ration\":300,\"out_delay\":0,\"ext_channel\":32,\"out_polarity\":0,\"channel\":"
    "0,\"input_descr\":\"Port 1 - Exposure\",\"dmi_incr\":0}"
};

// Details about vertex file
const MetaDataItemInfo RDB_RIEGL_VERTEX_INFO = {
    /* name        */ "riegl.vertex_info",
    /* title       */ "Vertex Information",
    /* description */ "Details about vertex file",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"properties\":{\"vertex_file\":{\"type\":\"object\",\"propert"
    "ies\":{\"file_uuid\":{\"type\":\"string\",\"description\":\"File's Universally "
    "Unique Identifier (RFC "
    "4122)\"},\"file_extension\":{\"type\":\"string\",\"description\":\"Vertex file "
    "extension, without the leading "
    "dot\"}},\"required\":[\"file_extension\"]}},\"title\":\"Vertex Information\",\"$"
    "schema\":\"http://json-schema.org/draft-04/schema#\",\"description\":\"Detai"
    "ls about vertex file\"}"
    ,
    /* example: */
    "{\"vertex_file\":{\"file_uuid\":\"51534d95-d71f-4f36-ae1a-3e63a21fd1c7\",\"fi"
    "le_extension\":\"vtx\"}}"
};

// Details about the voxels contained in the file
const MetaDataItemInfo RDB_RIEGL_VOXEL_INFO = {
    /* name        */ "riegl.voxel_info",
    /* title       */ "Voxel Information",
    /* description */ "Details about the voxels contained in the file",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"title\":\"Voxel Information\",\"$schema\":\"http://json-sc"
    "hema.org/draft-04/schema#\",\"description\":\"Details about the voxels "
    "contained in the file\",\"definitions\":{\"voxel_type\":{\"default\":\"centroi"
    "d\",\"enum\":[\"center\",\"centroid\",\"index\"],\"description\":\"Whether a point"
    " in a voxel represents its center or its centroid. If type is "
    "<tt>index</tt> there is no point but only an integer voxel index.\"},\"v"
    "oxel_origin_point\":{\"type\":\"array\",\"minItems\":3,\"maxItems\":3,\"items\":{"
    "\"type\":\"number\"},\"description\":\"Origin point for all voxel indices in "
    "voxel CRS.\"},\"voxel_size\":{\"type\":\"array\",\"minItems\":3,\"maxItems\":3,\"i"
    "tems\":{\"$ref\":\"#/definitions/edge_length\"},\"description\":\"Size of voxe"
    "ls.\"},\"voxel_origin_enum\":{\"default\":\"corner\",\"enum\":[\"center\",\"corner"
    "\"],\"description\":\"Defines whether the voxel's center or a corner is "
    "placed on CRS origin <tt>(0/0/0)</tt>.\"},\"shape_thresholds\":{\"type\":\"o"
    "bject\",\"properties\":{\"line\":{\"type\":\"number\",\"exclusiveMinimum\":true,\""
    "description\":\"If the biggest eigenvalue is bigger than the median "
    "eigenvalue * line_threshold, the voxel is considered a line.\",\"minimum"
    "\":1},\"plane\":{\"type\":\"number\",\"exclusiveMinimum\":true,\"description\":\"I"
    "f the smallest eigenvalue is smaller than the median eigenvalue * "
    "plane_threshold, the voxel is considered a plane.\",\"maximum\":1,\"minimu"
    "m\":0,\"exclusiveMaximum\":true}},\"required\":[\"plane\",\"line\"],\"descriptio"
    "n\":\"Thresholds used to compute the voxel's shape_id value.\"},\"edge_len"
    "gth\":{\"type\":\"number\",\"exclusiveMinimum\":true,\"description\":\"Length of"
    " voxel edge [m].\",\"minimum\":0},\"voxel_size_cubic\":{\"type\":\"number\",\"$r"
    "ef\":\"#/definitions/edge_length\"}},\"oneOf\":[{\"properties\":{\"size\":{\"des"
    "cription\":\"Size of voxels in file coordinate system.\",\"oneOf\":[{\"$ref\""
    ":\"#/definitions/voxel_size\"},{\"$ref\":\"#/definitions/voxel_size_cubic\"}"
    "]},\"shape_thresholds\":{\"$ref\":\"#/definitions/shape_thresholds\"},\"voxel"
    "_type\":{\"$ref\":\"#/definitions/voxel_type\"},\"voxel_origin\":{\"$ref\":\"#/d"
    "efinitions/voxel_origin_enum\"}},\"additionalProperties\":false,\"required"
    "\":[\"size\",\"voxel_origin\",\"voxel_type\"]},{\"properties\":{\"size\":{\"descri"
    "ption\":\"Size of voxels in file coordinate system.\",\"$ref\":\"#/definitio"
    "ns/voxel_size\"},\"reference_point\":{\"type\":\"array\",\"minItems\":2,\"maxIte"
    "ms\":2,\"items\":{\"type\":\"number\",\"maximum\":180,\"minimum\":-180},\"descript"
    "ion\":\"Point in WGS84 geodetic decimal degree (EPSG:4326) that was used"
    " to compute the projection distortion parameters. The coefficient "
    "order is latitude, longitude. Only voxels with corresponding geo_tag, "
    "voxel_size and reference_point can be reliably processed together. "
    "This entry is available for voxel files in projected CRS only.\"},\"shap"
    "e_thresholds\":{\"$ref\":\"#/definitions/shape_thresholds\"},\"size_llcs\":{\""
    "description\":\"Size of voxels in a locally levelled cartesian "
    "coordinate system (xyz). This is only used for voxels based on a map p"
    "rojection.\",\"$ref\":\"#/definitions/voxel_size\"},\"voxel_type\":{\"$ref\":\"#"
    "/definitions/voxel_type\"},\"voxel_origin\":{\"oneOf\":[{\"$ref\":\"#/definiti"
    "ons/voxel_origin_enum\"},{\"description\":\"The base point of the voxel "
    "grid. Used together with <tt>voxel_size</tt> and <tt>voxel_index</tt> "
    "to compute actual point coordinates.\",\"$ref\":\"#/definitions/voxel_orig"
    "in_point\"}]}},\"additionalProperties\":false,\"required\":[\"reference_poin"
    "t\",\"size_llcs\",\"size\",\"voxel_origin\",\"voxel_type\"]}]}"
    ,
    /* example: */
    "{\"size\":[0.5971642834779395,0.5971642834779395,0.5143705304787237],\"re"
    "ference_point\":[48,16],\"shape_thresholds\":{\"line\":6,\"plane\":0.16},\"siz"
    "e_llcs\":[0.5156575252891171,0.5130835356683303,0.5143705304787237],\"vo"
    "xel_type\":\"centroid\",\"voxel_origin\":\"corner\"}"
};

// Settings for waveform averaging
const MetaDataItemInfo RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS = {
    /* name        */ "riegl.waveform_averaging_settings",
    /* title       */ "Waveform Averaging Settings",
    /* description */ "Settings for waveform averaging",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"properties\":{\"num_shots\":{\"type\":\"integer\",\"minimum\""
    ":1,\"description\":\"Number of consecutive shots to be used for averaging"
    ".\"},\"mta_zone\":{\"type\":\"integer\",\"minimum\":1,\"description\":\"Fixed MTA "
    "zone for averaging.\"},\"trim\":{\"type\":\"number\",\"default\":0,\"maximum\":0."
    "5,\"minimum\":0,\"description\":\"Percentage for robust "
    "averaging.\"}},\"title\":\"Waveform Averaging Settings\",\"$schema\":\"http://"
    "json-schema.org/draft-04/schema#\",\"description\":\"Settings for waveform"
    " averaging\",\"required\":[\"num_shots\",\"mta_zone\"]}"
    ,
    /* example: */
    "{\"num_shots\":7,\"mta_zone\":1,\"trim\":0.05}"
};

// Details about waveform files
const MetaDataItemInfo RDB_RIEGL_WAVEFORM_INFO = {
    /* name        */ "riegl.waveform_info",
    /* title       */ "Waveform Information",
    /* description */ "Details about waveform files",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"properties\":{\"sample_data_files\":{\"type\":\"array\",\"it"
    "ems\":{\"type\":\"object\",\"properties\":{\"sample_bits\":{\"type\":\"integer\",\"e"
    "xclusiveMinimum\":false,\"description\":\"Bitwidth of samples (e.g. 10 "
    "bit, 12 bit)\",\"maximum\":32,\"minimum\":0,\"exclusiveMaximum\":false},\"delt"
    "a_st\":{\"type\":\"number\",\"description\":\"reserved\"},\"sample_interval\":{\"t"
    "ype\":\"number\",\"exclusiveMinimum\":false,\"description\":\"Sampling "
    "interval in seconds\",\"minimum\":0},\"laser_wavelength\":{\"type\":\"number\","
    "\"exclusiveMinimum\":false,\"description\":\"Laser wavelength in meters (0 "
    "= unknown)\",\"minimum\":0},\"file_extension\":{\"type\":\"string\",\"descriptio"
    "n\":\"Sample data file extension, without the leading dot\"},\"channel\":{\""
    "type\":\"integer\",\"exclusiveMinimum\":false,\"description\":\"Sample block "
    "channel number (255 = invalid)\",\"maximum\":255,\"minimum\":0,\"exclusiveMa"
    "ximum\":false},\"file_uuid\":{\"type\":\"string\",\"description\":\"File's "
    "Universally Unique Identifier (RFC "
    "4122)\"},\"channel_name\":{\"type\":\"string\",\"description\":\"Sample block "
    "channel name\"}},\"required\":[\"channel\",\"channel_name\",\"sample_interval\""
    ",\"sample_bits\",\"laser_wavelength\",\"delta_st\",\"file_extension\"]}},\"samp"
    "le_block_file\":{\"type\":\"object\",\"properties\":{\"file_uuid\":{\"type\":\"str"
    "ing\",\"description\":\"File's Universally Unique Identifier (RFC "
    "4122)\"},\"file_extension\":{\"type\":\"string\",\"description\":\"Sample block "
    "file extension, without the leading dot\"}},\"required\":[\"file_extension"
    "\"]},\"range_offset_waveform_samples_m\":{\"type\":\"number\",\"description\":\""
    "Calibrated device specific range offset for waveform samples in "
    "meters.\"},\"range_offset_m\":{\"type\":\"number\",\"description\":\"Calibrated "
    "device specific range offset for waveform analysis by system response "
    "fitting in meters.\"}},\"title\":\"Waveform Information\",\"$schema\":\"http:/"
    "/json-schema.org/draft-04/schema#\",\"description\":\"Details about "
    "waveform files\",\"required\":[\"sample_block_file\",\"sample_data_files\"]}"
    ,
    /* example: */
    "{\"sample_data_files\":[{\"sample_bits\":12,\"delta_st\":0,\"sample_interval\""
    ":1.00503e-09,\"laser_wavelength\":0,\"file_extension\":\"sp0\",\"channel\":0,\""
    "file_uuid\":\"da084413-e3e8-4655-a122-071de8490d8e\",\"channel_name\":\"high"
    "_power\"},{\"sample_bits\":12,\"delta_st\":0,\"sample_interval\":1.00503e-09,"
    "\"laser_wavelength\":0,\"file_extension\":\"sp1\",\"channel\":1,\"file_uuid\":\"9"
    "3585b5e-5ea9-43a1-947b-e7ba3be642d2\",\"channel_name\":\"low_power\"},{\"sam"
    "ple_bits\":12,\"delta_st\":0,\"sample_interval\":1.00503e-09,\"laser_wavelen"
    "gth\":0,\"file_extension\":\"sp5\",\"channel\":5,\"file_uuid\":\"9d2298c4-1036-4"
    "64f-b5cb-1cf8e517f3a0\",\"channel_name\":\"wwf\"}],\"sample_block_file\":{\"fi"
    "le_uuid\":\"93a03615-66c0-4bea-8ff8-c577378fe660\",\"file_extension\":\"sbx\""
    "},\"range_offset_m\":3.1415,\"range_offset_waveform_samples_m \":7.283}"
};

// Scanner settings for waveform output
const MetaDataItemInfo RDB_RIEGL_WAVEFORM_SETTINGS = {
    /* name        */ "riegl.waveform_settings",
    /* title       */ "Waveform Settings",
    /* description */ "Scanner settings for waveform output",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"array\",\"title\":\"Waveform Settings\",\"$schema\":\"http://json-sch"
    "ema.org/draft-04/schema#\",\"items\":{\"type\":\"object\",\"properties\":{\"pass"
    "_rng_less\":{\"type\":\"number\",\"description\":\"Threshold for range less "
    "than "
    "[m]\"},\"pass_rng_greater\":{\"type\":\"number\",\"description\":\"Threshold for"
    " range greater than "
    "[m]\"},\"smart_enabled\":{\"type\":\"boolean\",\"description\":\"Smart waveform "
    "output "
    "enabled\"},\"logic_expression\":{\"type\":\"string\",\"description\":\"Logic "
    "expression of smart waveforms "
    "filter\"},\"sbl_name\":{\"type\":\"string\",\"description\":\"Name of sample "
    "block, e.g.: wfm, "
    "wwf\"},\"pass_dev_greater\":{\"type\":\"integer\",\"description\":\"Threshold "
    "for deviation greater than "
    "[1]\"},\"enabled\":{\"type\":\"boolean\",\"description\":\"Waveform output "
    "enabled\"},\"channel_idx_mask\":{\"type\":\"integer\",\"description\":\"Bit mask"
    " for channels which belong to sbl_name: Channel 0 = Bit0, Channel 1 = "
    "Bit1, ...\"},\"pass_ampl_less\":{\"type\":\"number\",\"description\":\"Threshold"
    " for amplitude less than "
    "[dB]\"},\"pass_dev_less\":{\"type\":\"integer\",\"description\":\"Threshold for "
    "deviation less than "
    "[1]\"},\"pass_ampl_greater\":{\"type\":\"number\",\"description\":\"Threshold "
    "for amplitude greater than [dB]\"}},\"required\":[\"sbl_name\",\"enabled\",\"c"
    "hannel_idx_mask\"]},\"description\":\"Scanner settings for waveform "
    "output\"}"
    ,
    /* example: */
    "[{\"pass_rng_less\":13.11,\"pass_rng_greater\":9.27,\"smart_enabled\":true,\""
    "sbl_name\":\"wfm\",\"enabled\":true,\"channel_idx_mask\":11,\"pass_ampl_less\":"
    "5.0,\"pass_ampl_greater\":1.0},{\"sbl_name\":\"wwf\",\"enabled\":false,\"channe"
    "l_idx_mask\":32}]"
};

// Window analysis data estimated from scandata and resulting filter parameters
const MetaDataItemInfo RDB_RIEGL_WINDOW_ANALYSIS = {
    /* name        */ "riegl.window_analysis",
    /* title       */ "Window Analysis",
    /* description */ "Window analysis data estimated from scandata and resulting filter parameters",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"properties\":{\"settings\":{\"type\":\"object\",\"properties"
    "\":{\"amplitude\":{\"type\":\"object\",\"properties\":{\"sigma_factor\":{\"type\":\""
    "number\"},\"additive_value\":{\"type\":\"number\"}},\"required\":[\"sigma_factor"
    "\",\"additive_value\"]},\"range\":{\"type\":\"object\",\"properties\":{\"sigma_fac"
    "tor\":{\"type\":\"number\"},\"additive_value\":{\"type\":\"number\"}},\"required\":"
    "[\"sigma_factor\",\"additive_value\"]}},\"required\":[\"range\",\"amplitude\"]},"
    "\"filter\":{\"type\":\"object\",\"properties\":{\"range_min\":{\"type\":\"array\",\"i"
    "tems\":{\"type\":\"number\"},\"description\":\"[m]\"},\"angle\":{\"type\":\"array\",\""
    "items\":{\"type\":\"number\"},\"description\":\"[deg]\"},\"amplitude_max\":{\"type"
    "\":\"array\",\"items\":{\"type\":\"number\"},\"description\":\"[dB]\"},\"range_max\":"
    "{\"type\":\"array\",\"items\":{\"type\":\"number\"},\"description\":\"[m]\"}},\"requi"
    "red\":[\"angle\",\"range_min\",\"range_max\",\"amplitude_max\"]},\"result\":{\"typ"
    "e\":\"object\",\"properties\":{\"timestamp\":{\"type\":\"array\",\"items\":{\"type\":"
    "\"number\"},\"description\":\"[s]\"},\"range_sigma\":{\"type\":\"array\",\"items\":{"
    "\"type\":\"number\"},\"description\":\"[m]\"},\"amplitude_sigma\":{\"type\":\"array"
    "\",\"items\":{\"type\":\"number\"},\"description\":\"[dB]\"},\"amplitude_offset\":{"
    "\"type\":\"array\",\"items\":{\"type\":\"number\"},\"description\":\"[dB]\"},\"angle\""
    ":{\"type\":\"array\",\"items\":{\"type\":\"number\"},\"description\":\"[deg]\"},\"amp"
    "litude_mean\":{\"type\":\"array\",\"items\":{\"type\":\"number\"},\"description\":\""
    "[dB]\"},\"range_mean\":{\"type\":\"array\",\"items\":{\"type\":\"number\"},\"descrip"
    "tion\":\"[m]\"}},\"required\":[\"angle\",\"range_mean\",\"range_sigma\",\"amplitud"
    "e_mean\",\"amplitude_sigma\",\"amplitude_offset\"]}},\"title\":\"Window Analys"
    "is\",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"description\":"
    "\"Window analysis data estimated from scandata and resulting filter "
    "parameters\",\"required\":[\"result\",\"filter\",\"settings\"]}"
    ,
    /* example: */
    "{\"settings\":{\"amplitude\":{\"sigma_factor\":4,\"additive_value\":1.0},\"rang"
    "e\":{\"sigma_factor\":8,\"additive_value\":0.1}},\"filter\":{\"range_min\":[-0."
    "208,-0.21,-0.212,-0.214,-0.216,-0.218,-0.219,-0.221,-0.223,-0.225,-0.2"
    "27],\"angle\":[14.9,15.0,15.1,15.2,15.3,15.4,15.5,15.6,15.7,15.8,15.9],\""
    "amplitude_max\":[8.04,8.01,7.99,7.96,7.93,7.9,7.88,7.85,7.83,7.8,7.78],"
    "\"range_max\":[0.424,0.425,0.426,0.427,0.428,0.428,0.429,0.43,0.431,0.43"
    "1,0.432]},\"result\":{\"timestamp\":[408.4441,411.4443],\"range_sigma\":[0.0"
    "1869652,0.02151435,0.01747969,0.01918765,0.01945776,0.01934862,0.01955"
    "329,0.02225589,0.02229977,0.01899122,0.02009433],\"amplitude_sigma\":[0."
    "4272844,0.4298479,0.4236816,0.4283583,0.4362353,0.4315141,0.4373984,0."
    "4472798,0.4346001,0.4345487,0.4540681],\"amplitude_offset\":[1.9,1.9],\"a"
    "ngle\":[14.9,15.0,15.1,15.2,15.3,15.4,15.5,15.6,15.7,15.8,15.9],\"amplit"
    "ude_mean\":[5.347396,5.263155,5.224655,5.179926,5.097782,5.116479,5.051"
    "756,4.983473,5.007885,5.002441,4.982],\"range_mean\":[0.1105621,0.107956"
    "4,0.1087088,0.1067261,0.1054582,0.1090412,0.102871,0.1019044,0.1051523"
    ",0.1058445,0.1031261]}}"
};

// Correction parameters for window glass echoes
const MetaDataItemInfo RDB_RIEGL_WINDOW_ECHO_CORRECTION = {
    /* name        */ "riegl.window_echo_correction",
    /* title       */ "Window Echo Correction",
    /* description */ "Correction parameters for window glass echoes",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"properties\":{\"range\":{\"type\":\"object\",\"properties\":{"
    "\"maximum\":{\"type\":\"number\",\"maximum\":2.0,\"minimum\":-2.0,\"description\":"
    "\"Maximum range in m\"},\"minimum\":{\"type\":\"number\",\"maximum\":2.0,\"minimu"
    "m\":-2.0,\"description\":\"Minimum range in "
    "m\"},\"entries\":{\"type\":\"integer\",\"minimum\":1,\"description\":\"Number of "
    "range entries\"}},\"required\":[\"minimum\",\"maximum\",\"entries\"],\"descripti"
    "on\":\"Range axis of correction table\"},\"slices\":{\"type\":\"array\",\"items\""
    ":{\"type\":\"object\",\"properties\":{\"table\":{\"type\":\"array\",\"minItems\":1,\""
    "items\":{\"type\":\"array\",\"minItems\":1,\"items\":{\"type\":\"array\",\"minItems\""
    ":3,\"maxItems\":3,\"items\":{\"type\":\"number\",\"description\":\"Table cell "
    "(item 0: amplitude in dB, 1: range in m, 2: "
    "flags)\"},\"description\":\"Table column (= range "
    "axis)\"},\"description\":\"Table row (= amplitude "
    "axis)\"},\"description\":\"Correction table (dimension defined by the "
    "'amplitude' and 'range' "
    "objects)\"},\"amplitude\":{\"type\":\"number\",\"description\":\"Window echo "
    "amplitude of slice in "
    "dB\"}},\"required\":[\"amplitude\",\"table\"],\"description\":\"Window echo "
    "correction parameter slice\"}},\"amplitude\":{\"type\":\"object\",\"properties"
    "\":{\"maximum\":{\"type\":\"number\",\"minimum\":0.0,\"description\":\"Maximum "
    "amplitude in "
    "dB\"},\"minimum\":{\"type\":\"number\",\"minimum\":0.0,\"description\":\"Minimum "
    "amplitude in "
    "dB\"},\"entries\":{\"type\":\"integer\",\"minimum\":1,\"description\":\"Number of "
    "amplitude entries\"}},\"required\":[\"minimum\",\"maximum\",\"entries\"],\"descr"
    "iption\":\"Amplitude axis of correction table\"}},\"title\":\"Window Echo Co"
    "rrection\",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"descrip"
    "tion\":\"Correction parameters for window glass "
    "echoes\",\"required\":[\"amplitude\",\"range\",\"slices\"]}"
    ,
    /* example: */
    "{\"range\":{\"maximum\":1.5060822940732335,\"minimum\":-1.5060822940732335,\""
    "entries\":128},\"slices\":[{\"table\":[[[6.23,0.3535,1]],[[5.54,0.72375,1]]"
    "],\"amplitude\":1.5},{\"table\":[[[6.23,0.3535,1]],[[5.54,0.72375,1]]],\"am"
    "plitude\":2.0}],\"amplitude\":{\"maximum\":20,\"minimum\":2,\"entries\":128}}"
};

// Table of all meta data item details records
const MetaDataItemInfo* const RDB_META_DATA_ITEMS[] = {
    &RDB_RIEGL_ANGULAR_NOTCH_FILTER,
    &RDB_RIEGL_ATMOSPHERE,
    &RDB_RIEGL_BEAM_GEOMETRY,
    &RDB_RIEGL_CONTROL_OBJECT_CATALOG,
    &RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE,
    &RDB_RIEGL_DETECTION_PROBABILITY,
    &RDB_RIEGL_DEVICE,
    &RDB_RIEGL_DEVICE_GEOMETRY,
    &RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL,
    &RDB_RIEGL_DEVICE_OUTPUT_LIMITS,
    &RDB_RIEGL_DEVICES,
    &RDB_RIEGL_DYNTRIG,
    &RDB_RIEGL_ECHO_INFO,
    &RDB_RIEGL_EXPONENTIAL_DECOMPOSITION,
    &RDB_RIEGL_GAUSSIAN_DECOMPOSITION,
    &RDB_RIEGL_GEO_TAG,
    &RDB_RIEGL_GEOMETRIC_SCALE_FACTOR,
    &RDB_RIEGL_GEOREFERENCING_PARAMETERS,
    &RDB_RIEGL_ITEM_NAMES,
    &RDB_RIEGL_LICENSES,
    &RDB_RIEGL_MTA_SETTINGS,
    &RDB_RIEGL_NEAR_RANGE_CORRECTION,
    &RDB_RIEGL_NOISE_ESTIMATES,
    &RDB_RIEGL_NOTCH_FILTER,
    &RDB_RIEGL_PIXEL_INFO,
    &RDB_RIEGL_PLANE_PATCH_MATCHING,
    &RDB_RIEGL_PLANE_PATCH_STATISTICS,
    &RDB_RIEGL_PLANE_SLOPE_CLASS_INFO,
    &RDB_RIEGL_POINT_ATTRIBUTE_GROUPS,
    &RDB_RIEGL_POINTCLOUD_INFO,
    &RDB_RIEGL_POSE_ESTIMATION,
    &RDB_RIEGL_POSE_SENSORS,
    &RDB_RIEGL_PULSE_POSITION_MODULATION,
    &RDB_RIEGL_RANGE_STATISTICS,
    &RDB_RIEGL_RECEIVER_INTERNALS,
    &RDB_RIEGL_REFLECTANCE_CALCULATION,
    &RDB_RIEGL_REFLECTANCE_CORRECTION,
    &RDB_RIEGL_SCAN_PATTERN,
    &RDB_RIEGL_SHOT_INFO,
    &RDB_RIEGL_STORED_FILTERS,
    &RDB_RIEGL_SYSTEM_DESCRIPTION,
    &RDB_RIEGL_TEMPERATURE_CALCULATION,
    &RDB_RIEGL_TIME_BASE,
    &RDB_RIEGL_TRAJECTORY_INFO,
    &RDB_RIEGL_TTIP_CONFIGURATION,
    &RDB_RIEGL_VERTEX_INFO,
    &RDB_RIEGL_VOXEL_INFO,
    &RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS,
    &RDB_RIEGL_WAVEFORM_INFO,
    &RDB_RIEGL_WAVEFORM_SETTINGS,
    &RDB_RIEGL_WINDOW_ANALYSIS,
    &RDB_RIEGL_WINDOW_ECHO_CORRECTION
};
const std::size_t RDB_META_DATA_ITEM_COUNT(
    sizeof(RDB_META_DATA_ITEMS) / sizeof(RDB_META_DATA_ITEMS[0])
);
const std::vector<const MetaDataItemInfo*> RDB_META_DATA_ITEMS_VECTOR(
    RDB_META_DATA_ITEMS, RDB_META_DATA_ITEMS + RDB_META_DATA_ITEM_COUNT
);

}}} // namespace riegl::rdb::pointcloud

#endif // RDB_354CFFB3_BDAA_4E38_98C8_9C09D0C0AD87
